# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

INIT_USER_DOTFILES_PY_METADATA = Metadata(
    id="46bf1c58977e7bced1c1fbd2f6c4642aa3fe2ecd.boutiques",
    name="init_user_dotfiles.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class InitUserDotfilesPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `init_user_dotfiles_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def init_user_dotfiles_py(
    help_: bool = False,
    help_dotfiles_all: bool = False,
    help_dotfiles_mod: bool = False,
    help_shells: bool = False,
    hist: bool = False,
    show_valid_opts: bool = False,
    ver: bool = False,
    dot_files_list: list[str] | None = None,
    dir_bin: str | None = None,
    dir_dot: str | None = None,
    do_updates: list[str] | None = None,
    dry_run: bool = False,
    force: bool = False,
    make_backup: str | None = None,
    shell_list: list[str] | None = None,
    test: bool = False,
    verbosity_level: int | None = None,
    runner: Runner | None = None,
) -> InitUserDotfilesPyOutputs:
    """
    Initialize or evaluate user dot files (.cshrc, .bashrc, ...) for system
    settings.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/init_user_dotfiles.py.html
    
    Args:
        help_: Show this help.
        help_dotfiles_all: Display dot files known by the program.
        help_dotfiles_mod: Display modifiable dot files.
        help_shells: Display shells known by the program.
        hist: Show module history.
        show_valid_opts: List valid options.
        ver: Show current version.
        dot_files_list: Specify dot files to focus on (default from\
            -help_dotfiles_mod).
        dir_bin: Specify bin directory to add to PATH (default comes from\
            `which afni_proc.py`).
        dir_dot: Specify directory containing dot files.
        do_updates: Specify which updates to make (default is nothing).
        dry_run: Do not modify files, but see what would happen.
        force: Force edits, whether they seem needed or not.
        make_backup: Specify whether to make backups of originals (default is\
            yes).
        shell_list: Specify shells instead of using -dflist.
        test: Just test the files for potential changes.
        verbosity_level: Set the verbosity level (default 1).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `InitUserDotfilesPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(INIT_USER_DOTFILES_PY_METADATA)
    cargs = []
    cargs.append("init_user_dotfiles.py")
    if help_:
        cargs.append("-help")
    if help_dotfiles_all:
        cargs.append("-help_dotfiles_all")
    if help_dotfiles_mod:
        cargs.append("-help_dotfiles_mod")
    if help_shells:
        cargs.append("-help_shells")
    if hist:
        cargs.append("-hist")
    if show_valid_opts:
        cargs.append("-show_valid_opts")
    if ver:
        cargs.append("-ver")
    if dot_files_list is not None:
        cargs.extend([
            "-dflist",
            *dot_files_list
        ])
    if dir_bin is not None:
        cargs.extend([
            "-dir_bin",
            dir_bin
        ])
    if dir_dot is not None:
        cargs.extend([
            "-dir_dot",
            dir_dot
        ])
    if do_updates is not None:
        cargs.extend([
            "-do_updates",
            *do_updates
        ])
    if dry_run:
        cargs.append("-dry_run")
    if force:
        cargs.append("-force")
    if make_backup is not None:
        cargs.extend([
            "-make_backup",
            make_backup
        ])
    if shell_list is not None:
        cargs.extend([
            "-shell_list",
            *shell_list
        ])
    if test:
        cargs.append("-test")
    if verbosity_level is not None:
        cargs.extend([
            "-verb",
            str(verbosity_level)
        ])
    ret = InitUserDotfilesPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "INIT_USER_DOTFILES_PY_METADATA",
    "InitUserDotfilesPyOutputs",
    "init_user_dotfiles_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PAIRREG_METADATA = Metadata(
    id="8107f07a5a681ee7ce20b9004ac2037129388509.boutiques",
    name="pairreg",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class PairregOutputs(typing.NamedTuple):
    """
    Output object returned when calling `pairreg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_matrix: OutputPathType
    """Pairwise registration output transformation matrix file"""


def pairreg(
    brain1: InputPathType,
    brain2: InputPathType,
    skull1: InputPathType,
    skull2: InputPathType,
    outputmatrix: InputPathType,
    extra_flirt_args: str | None = None,
    runner: Runner | None = None,
) -> PairregOutputs:
    """
    Pairwise registration tool.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FLIRT
    
    Args:
        brain1: Brain image 1 (used as -ref internally).
        brain2: Brain image 2.
        skull1: Skull image 1 (used as -ref internally).
        skull2: Skull image 2.
        outputmatrix: Output transformation matrix file.
        extra_flirt_args: Extra arguments to pass to flirt.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PairregOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PAIRREG_METADATA)
    cargs = []
    cargs.append("/usr/local/fsl/bin/pairreg")
    cargs.append(execution.input_file(brain1))
    cargs.append(execution.input_file(brain2))
    cargs.append(execution.input_file(skull1))
    cargs.append(execution.input_file(skull2))
    cargs.append(execution.input_file(outputmatrix))
    if extra_flirt_args is not None:
        cargs.append(extra_flirt_args)
    ret = PairregOutputs(
        root=execution.output_file("."),
        output_matrix=execution.output_file(pathlib.Path(outputmatrix).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PAIRREG_METADATA",
    "PairregOutputs",
    "pairreg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF_LAYERS_METADATA = Metadata(
    id="604623c15444cbe34d0c899c05275654059b94ce.boutiques",
    name="SurfLayers",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfLayersOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf_layers(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    interpolated_surfaces: OutputPathType | None
    """Interpolated surfaces files"""
    additional_spec_files: OutputPathType | None
    """Additional files if -spec option was used"""
    run_view_script: OutputPathType | None
    """Run script to view output directly"""


def surf_layers(
    spec_dset: InputPathType | None = None,
    outdir: str | None = None,
    states: str | None = None,
    hemi: str | None = None,
    n_intermed_surfs: float | None = None,
    surf_a: InputPathType | None = None,
    surf_b: InputPathType | None = None,
    surf_intermed_pref: str | None = None,
    echo: bool = False,
    no_clean: bool = False,
    runner: Runner | None = None,
) -> SurfLayersOutputs:
    """
    Compute intermediate equi-distant surfaces between two boundary surfaces.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/SurfLayers.html
    
    Args:
        spec_dset: Dataset that is the SUMA specification file describing input\
            surfaces.
        outdir: New directory for output (default: surflayers).
        states: Typically smoothwm, pial states to describe inner and outer\
            surfaces (default: 'smoothwm pial').
        hemi: Choose hemisphere: 'lh', 'rh', or 'lh rh' (for both).
        n_intermed_surfs: Total number of intermediate surfaces to create.
        surf_a: Inner boundary surface by filename (e.g., smoothwm.gii).
        surf_b: Outer boundary surface by filename (e.g., pial.gii).
        surf_intermed_pref: Name for interpolated surfaces (default: isurf).
        echo: Run script with 'set echo' (i.e., verbosely).
        no_clean: Do not remove temp files (probably just for testing).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfLayersOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF_LAYERS_METADATA)
    cargs = []
    cargs.append("SurfLayers")
    if spec_dset is not None:
        cargs.extend([
            "-spec",
            execution.input_file(spec_dset)
        ])
    if outdir is not None:
        cargs.extend([
            "-outdir",
            outdir
        ])
    if states is not None:
        cargs.extend([
            "-states",
            states
        ])
    if hemi is not None:
        cargs.extend([
            "-hemi",
            hemi
        ])
    if n_intermed_surfs is not None:
        cargs.extend([
            "-n_intermed_surfs",
            str(n_intermed_surfs)
        ])
    if surf_a is not None:
        cargs.extend([
            "-surf_A",
            execution.input_file(surf_a)
        ])
    if surf_b is not None:
        cargs.extend([
            "-surf_B",
            execution.input_file(surf_b)
        ])
    if surf_intermed_pref is not None:
        cargs.extend([
            "-surf_intermed_pref",
            surf_intermed_pref
        ])
    if echo:
        cargs.append("-echo")
    if no_clean:
        cargs.append("-no_clean")
    ret = SurfLayersOutputs(
        root=execution.output_file("."),
        interpolated_surfaces=execution.output_file(outdir + "/isurf." + hemi + ".*.gii") if (outdir is not None and hemi is not None) else None,
        additional_spec_files=execution.output_file(outdir + "/*") if (outdir is not None) else None,
        run_view_script=execution.output_file(outdir + "/run*tcsh") if (outdir is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF_LAYERS_METADATA",
    "SurfLayersOutputs",
    "surf_layers",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TSMOOTH_METADATA = Metadata(
    id="13bf91f18e7446955f1c082671ec122a2283b13e.boutiques",
    name="3dTsmooth",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTsmoothOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_tsmooth(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType
    """Smoothed 3D+time dataset"""


def v_3d_tsmooth(
    input_dataset: InputPathType,
    runner: Runner | None = None,
) -> V3dTsmoothOutputs:
    """
    Smooths each voxel time series in a 3D+time dataset and produces as output a new
    3D+time dataset (e.g., lowpass filter in time).
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dTsmooth.html
    
    Args:
        input_dataset: The input 3D+time dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTsmoothOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TSMOOTH_METADATA)
    cargs = []
    cargs.append("3dTsmooth")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(input_dataset))
    ret = V3dTsmoothOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file("[PREFIX].nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTsmoothOutputs",
    "V_3D_TSMOOTH_METADATA",
    "v_3d_tsmooth",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SIENA_FLIRT_METADATA = Metadata(
    id="43c7f5fc0eb419d283af74ab74f219134df428d4.boutiques",
    name="siena_flirt",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class SienaFlirtOutputs(typing.NamedTuple):
    """
    Output object returned when calling `siena_flirt(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_transform_matrix: OutputPathType
    """Output transformation matrix file"""
    output_registered_image: OutputPathType
    """Output registered image"""


def siena_flirt(
    input1_fileroot: str,
    input2_fileroot: str,
    runner: Runner | None = None,
) -> SienaFlirtOutputs:
    """
    Wrapper for FLIRT image registration within the SIENA framework.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    Args:
        input1_fileroot: First input file root (e.g. first time-point image\
            root, without file extension).
        input2_fileroot: Second input file root (e.g. second time-point image\
            root, without file extension).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SienaFlirtOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SIENA_FLIRT_METADATA)
    cargs = []
    cargs.append("siena_flirt")
    cargs.append(input1_fileroot)
    cargs.append(input2_fileroot)
    ret = SienaFlirtOutputs(
        root=execution.output_file("."),
        output_transform_matrix=execution.output_file(input1_fileroot + "_to_" + input2_fileroot + "_flirt.mat"),
        output_registered_image=execution.output_file(input1_fileroot + "_to_" + input2_fileroot + "_flirt.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SIENA_FLIRT_METADATA",
    "SienaFlirtOutputs",
    "siena_flirt",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

QDELAUNAY_METADATA = Metadata(
    id="230edbfb789d820a73d4a6e8222bf0d4bc599486.boutiques",
    name="qdelaunay",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class QdelaunayOutputs(typing.NamedTuple):
    """
    Output object returned when calling `qdelaunay(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def qdelaunay(
    input_file: InputPathType,
    runner: Runner | None = None,
) -> QdelaunayOutputs:
    """
    Compute the Delaunay triangulation using Qhull.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/qdelaunay.html
    
    Args:
        input_file: Input file containing point coordinates.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `QdelaunayOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(QDELAUNAY_METADATA)
    cargs = []
    cargs.append("qdelaunay")
    cargs.append("[OPTION_FLAGS]")
    cargs.append("<")
    cargs.append(execution.input_file(input_file))
    ret = QdelaunayOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "QDELAUNAY_METADATA",
    "QdelaunayOutputs",
    "qdelaunay",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GREEDY_METADATA = Metadata(
    id="fa0c2cc85074ae69ac2d7bc0d952e7394fbf5077.boutiques",
    name="greedy",
    package="greedy",
    container_image_tag="pyushkevich/itksnap:v3.8.2",
)


class GreedyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `greedy_(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """Output file from affine"""
    reslice_output_file: OutputPathType | None
    """Resliced output image"""


def greedy_(
    dimensions: int,
    threads: int | None = None,
    metric: typing.Literal["SSD", "MI", "NMI", "NCC", "MAHAL"] | None = None,
    affine: bool = False,
    affine_dof: int | None = None,
    ia_identity: bool = False,
    iterations: str | None = None,
    fixed_mask: InputPathType | None = None,
    moving_mask: InputPathType | None = None,
    input_images: list[InputPathType] | None = None,
    output: str | None = None,
    fixed_reslicing_image: InputPathType | None = None,
    reslice_moving_image: InputPathType | None = None,
    reslice_output_image: str | None = None,
    reslice: InputPathType | None = None,
    verbosity: int | None = None,
    runner: Runner | None = None,
) -> GreedyOutputs:
    """
    Paul's greedy diffeomorphic registration implementation.
    
    Args:
        dimensions: Number of image dimensions.
        threads: Number of allowed concurrent threads.
        metric: Metric for the entire registration.
        affine: Perform affine registration and save to output (-o).
        affine_dof: Degrees of freedom for affine registration.
        ia_identity: initialize affine matrix based on NIFTI headers.
        iterations: Number of iterations per level of multi-res.
        fixed_mask: Fixed image mask.
        moving_mask: Moving image mask.
        input_images: Image pair (may be repeated).
        output: Output file.
        fixed_reslicing_image: fixed image for reslicing.
        reslice_moving_image: Moving image reslice file.
        reslice_output_image: Output image reslice file.
        reslice: Reslice images instead of doing registration.
        verbosity: Verbosity level.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GreedyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GREEDY_METADATA)
    cargs = []
    cargs.append("greedy")
    if threads is not None:
        cargs.extend([
            "-threads",
            str(threads)
        ])
    cargs.extend([
        "-d",
        str(dimensions)
    ])
    if metric is not None:
        cargs.extend([
            "-m",
            metric
        ])
    if affine:
        cargs.append("-a")
    if affine_dof is not None:
        cargs.extend([
            "-dof",
            str(affine_dof)
        ])
    if ia_identity:
        cargs.append("-ia-identity")
    if iterations is not None:
        cargs.extend([
            "-n",
            iterations
        ])
    if fixed_mask is not None:
        cargs.extend([
            "-gm",
            execution.input_file(fixed_mask)
        ])
    if moving_mask is not None:
        cargs.extend([
            "-mm",
            execution.input_file(moving_mask)
        ])
    if input_images is not None:
        cargs.extend([
            "-i",
            *[execution.input_file(f) for f in input_images]
        ])
    if output is not None:
        cargs.extend([
            "-o",
            output
        ])
    if fixed_reslicing_image is not None:
        cargs.extend([
            "-rf",
            execution.input_file(fixed_reslicing_image)
        ])
    if reslice_moving_image is not None:
        cargs.extend([
            "-rm",
            execution.input_file(reslice_moving_image)
        ])
    if reslice_output_image is not None:
        cargs.append(reslice_output_image)
    if reslice is not None:
        cargs.extend([
            "-r",
            execution.input_file(reslice)
        ])
    if verbosity is not None:
        cargs.extend([
            "-V",
            str(verbosity)
        ])
    ret = GreedyOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output) if (output is not None) else None,
        reslice_output_file=execution.output_file(reslice_output_image) if (reslice_output_image is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GREEDY_METADATA",
    "GreedyOutputs",
    "greedy_",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TCKEDIT_METADATA = Metadata(
    id="cd40d2e3c8767f7171bda0ed685c6efb24bb6199.boutiques",
    name="tckedit",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class TckeditInclude:
    """
    specify an inclusion region of interest, as either a binary mask image, or
    as a sphere using 4 comma-separared values (x,y,z,radius). Streamlines must
    traverse ALL inclusion regions to be accepted.
    """
    spec: str
    """specify an inclusion region of interest, as either a binary mask image,
    or as a sphere using 4 comma-separared values (x,y,z,radius). Streamlines
    must traverse ALL inclusion regions to be accepted."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-include")
        cargs.append(self.spec)
        return cargs


@dataclasses.dataclass
class TckeditIncludeOrdered:
    """
    specify an inclusion region of interest, as either a binary mask image, or
    as a sphere using 4 comma-separared values (x,y,z,radius). Streamlines must
    traverse ALL inclusion_ordered regions in the order they are specified in
    order to be accepted.
    """
    image: str
    """specify an inclusion region of interest, as either a binary mask image,
    or as a sphere using 4 comma-separared values (x,y,z,radius). Streamlines
    must traverse ALL inclusion_ordered regions in the order they are specified
    in order to be accepted."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-include_ordered")
        cargs.append(self.image)
        return cargs


@dataclasses.dataclass
class TckeditExclude:
    """
    specify an exclusion region of interest, as either a binary mask image, or
    as a sphere using 4 comma-separared values (x,y,z,radius). Streamlines that
    enter ANY exclude region will be discarded.
    """
    spec: str
    """specify an exclusion region of interest, as either a binary mask image,
    or as a sphere using 4 comma-separared values (x,y,z,radius). Streamlines
    that enter ANY exclude region will be discarded."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-exclude")
        cargs.append(self.spec)
        return cargs


@dataclasses.dataclass
class TckeditMask:
    """
    specify a masking region of interest, as either a binary mask image, or as a
    sphere using 4 comma-separared values (x,y,z,radius). If defined,
    streamlines exiting the mask will be truncated.
    """
    spec: str
    """specify a masking region of interest, as either a binary mask image, or
    as a sphere using 4 comma-separared values (x,y,z,radius). If defined,
    streamlines exiting the mask will be truncated."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-mask")
        cargs.append(self.spec)
        return cargs


@dataclasses.dataclass
class TckeditConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class TckeditOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tckedit(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    tracks_out: OutputPathType
    """the output track file"""
    tck_weights_out: OutputPathType | None
    """specify the path for an output text scalar file containing streamline
    weights """


def tckedit(
    tracks_in: list[InputPathType],
    tracks_out: str,
    include: list[TckeditInclude] | None = None,
    include_ordered: list[TckeditIncludeOrdered] | None = None,
    exclude: list[TckeditExclude] | None = None,
    mask: list[TckeditMask] | None = None,
    maxlength: float | None = None,
    minlength: float | None = None,
    number: int | None = None,
    skip: int | None = None,
    maxweight: float | None = None,
    minweight: float | None = None,
    inverse: bool = False,
    ends_only: bool = False,
    tck_weights_in: InputPathType | None = None,
    tck_weights_out: str | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[TckeditConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> TckeditOutputs:
    """
    Perform various editing operations on track files.
    
    This command can be used to perform various types of manipulations on track
    data. A range of such manipulations are demonstrated in the examples
    provided below.
    
    References:
    
    .
    
    Author: Robert E. Smith (robert.smith@florey.edu.au)
    
    URL: https://mrtrix.readthedocs.io/en/latest/reference/commands/tckedit.html
    
    Args:
        tracks_in: the input track file(s).
        tracks_out: the output track file.
        include: specify an inclusion region of interest, as either a binary\
            mask image, or as a sphere using 4 comma-separared values\
            (x,y,z,radius). Streamlines must traverse ALL inclusion regions to be\
            accepted.
        include_ordered: specify an inclusion region of interest, as either a\
            binary mask image, or as a sphere using 4 comma-separared values\
            (x,y,z,radius). Streamlines must traverse ALL inclusion_ordered regions\
            in the order they are specified in order to be accepted.
        exclude: specify an exclusion region of interest, as either a binary\
            mask image, or as a sphere using 4 comma-separared values\
            (x,y,z,radius). Streamlines that enter ANY exclude region will be\
            discarded.
        mask: specify a masking region of interest, as either a binary mask\
            image, or as a sphere using 4 comma-separared values (x,y,z,radius). If\
            defined, streamlines exiting the mask will be truncated.
        maxlength: set the maximum length of any streamline in mm.
        minlength: set the minimum length of any streamline in mm.
        number: set the desired number of selected streamlines to be propagated\
            to the output file.
        skip: omit this number of selected streamlines before commencing\
            writing to the output file.
        maxweight: set the maximum weight of any streamline.
        minweight: set the minimum weight of any streamline.
        inverse: output the inverse selection of streamlines based on the\
            criteria provided; i.e. only those streamlines that fail at least one\
            selection criterion, and/or vertices that are outside masks if\
            provided, will be written to file.
        ends_only: only test the ends of each streamline against the provided\
            include/exclude ROIs.
        tck_weights_in: specify a text scalar file containing the streamline\
            weights.
        tck_weights_out: specify the path for an output text scalar file\
            containing streamline weights.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TckeditOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TCKEDIT_METADATA)
    cargs = []
    cargs.append("tckedit")
    if include is not None:
        cargs.extend([a for c in [s.run(execution) for s in include] for a in c])
    if include_ordered is not None:
        cargs.extend([a for c in [s.run(execution) for s in include_ordered] for a in c])
    if exclude is not None:
        cargs.extend([a for c in [s.run(execution) for s in exclude] for a in c])
    if mask is not None:
        cargs.extend([a for c in [s.run(execution) for s in mask] for a in c])
    if maxlength is not None:
        cargs.extend([
            "-maxlength",
            str(maxlength)
        ])
    if minlength is not None:
        cargs.extend([
            "-minlength",
            str(minlength)
        ])
    if number is not None:
        cargs.extend([
            "-number",
            str(number)
        ])
    if skip is not None:
        cargs.extend([
            "-skip",
            str(skip)
        ])
    if maxweight is not None:
        cargs.extend([
            "-maxweight",
            str(maxweight)
        ])
    if minweight is not None:
        cargs.extend([
            "-minweight",
            str(minweight)
        ])
    if inverse:
        cargs.append("-inverse")
    if ends_only:
        cargs.append("-ends_only")
    if tck_weights_in is not None:
        cargs.extend([
            "-tck_weights_in",
            execution.input_file(tck_weights_in)
        ])
    if tck_weights_out is not None:
        cargs.extend([
            "-tck_weights_out",
            tck_weights_out
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.extend([execution.input_file(f) for f in tracks_in])
    cargs.append(tracks_out)
    ret = TckeditOutputs(
        root=execution.output_file("."),
        tracks_out=execution.output_file(tracks_out),
        tck_weights_out=execution.output_file(tck_weights_out) if (tck_weights_out is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TCKEDIT_METADATA",
    "TckeditConfig",
    "TckeditExclude",
    "TckeditInclude",
    "TckeditIncludeOrdered",
    "TckeditMask",
    "TckeditOutputs",
    "tckedit",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_RANK_METADATA = Metadata(
    id="3003fb7861d0366b3de9ce16dec83be8cdbe44e5.boutiques",
    name="3dRank",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dRankOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_rank(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset_head: OutputPathType
    """Main output dataset in AFNI format (.HEAD file)"""
    output_dataset_brik: OutputPathType
    """Main output dataset in AFNI format (.BRIK file)"""
    rank_map_file: OutputPathType
    """Rank map 1D file showing the mapping from the rank to the integral values
    in the input dataset"""


def v_3d_rank(
    runner: Runner | None = None,
) -> V3dRankOutputs:
    """
    Replaces voxel values by their rank in the set of values collected over all
    voxels in all input datasets.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dRank.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dRankOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_RANK_METADATA)
    cargs = []
    cargs.append("3dRank")
    cargs.append("[-prefix")
    cargs.append("PREFIX]")
    cargs.append("<-input")
    cargs.append("DATASET1")
    cargs.append("[DATASET2")
    cargs.append("...]>")
    ret = V3dRankOutputs(
        root=execution.output_file("."),
        output_dataset_head=execution.output_file("[PREFIX]*.HEAD"),
        output_dataset_brik=execution.output_file("[PREFIX]*.BRIK"),
        rank_map_file=execution.output_file("[PREFIX]*.1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dRankOutputs",
    "V_3D_RANK_METADATA",
    "v_3d_rank",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ALIGN_EPI_ANAT_PY_METADATA = Metadata(
    id="cbd28c0cb9cd06edf98debca6a2d69094dae119d.boutiques",
    name="align_epi_anat.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AlignEpiAnatPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `align_epi_anat_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    anat_aligned: OutputPathType
    """A version of the anatomy that is aligned to the EPI"""
    epi_aligned: OutputPathType
    """A version of the EPI dataset aligned to the Anatomy"""


def align_epi_anat_py(
    epi: InputPathType,
    anat: InputPathType,
    epi_base: str,
    runner: Runner | None = None,
) -> AlignEpiAnatPyOutputs:
    """
    Align EPI to anatomical datasets or vice versa.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/align_epi_anat.py.html
    
    Args:
        epi: EPI dataset to align or to which to align.
        anat: Anatomical dataset to align or to which to align.
        epi_base: Base sub-brick to use for alignment\
            (0/mean/median/max/subbrick#).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AlignEpiAnatPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ALIGN_EPI_ANAT_PY_METADATA)
    cargs = []
    cargs.append("align_epi_anat.py")
    cargs.extend([
        "-epi",
        execution.input_file(epi)
    ])
    cargs.extend([
        "-anat",
        execution.input_file(anat)
    ])
    cargs.extend([
        "-epi_base",
        epi_base
    ])
    cargs.append("[OUTPUT_OPTIONS]")
    cargs.append("[ALIGNMENT_OPTIONS]")
    cargs.append("[PREPROCESSING_OPTIONS]")
    ret = AlignEpiAnatPyOutputs(
        root=execution.output_file("."),
        anat_aligned=execution.output_file("[ANAT]+orig"),
        epi_aligned=execution.output_file("[EPI]+orig"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ALIGN_EPI_ANAT_PY_METADATA",
    "AlignEpiAnatPyOutputs",
    "align_epi_anat_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BORDER_MERGE_METADATA = Metadata(
    id="1d200d400a3bde437012659361326bb4479ca32b.boutiques",
    name="border-merge",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class BorderMergeUpTo:
    """
    use an inclusive range of borders.
    """
    last_border: str
    """the number or name of the last column to include"""
    opt_reverse: bool = False
    """use the range in reverse order"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-up-to")
        cargs.append(self.last_border)
        if self.opt_reverse:
            cargs.append("-reverse")
        return cargs


@dataclasses.dataclass
class BorderMergeSelect:
    """
    select a single border to use.
    """
    border: str
    """the border number or name"""
    up_to: BorderMergeUpTo | None = None
    """use an inclusive range of borders"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-select")
        cargs.append(self.border)
        if self.up_to is not None:
            cargs.extend(self.up_to.run(execution))
        return cargs


@dataclasses.dataclass
class BorderMergeBorder:
    """
    specify an input border file.
    """
    border_file_in: InputPathType
    """a border file to use borders from"""
    select_: list[BorderMergeSelect] | None = None
    """select a single border to use"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-border")
        cargs.append(execution.input_file(self.border_file_in))
        if self.select_ is not None:
            cargs.extend([a for c in [s.run(execution) for s in self.select_] for a in c])
        return cargs


class BorderMergeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `border_merge(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    border_file_out: OutputPathType
    """the output border file"""


def border_merge(
    border_file_out: str,
    border: list[BorderMergeBorder] | None = None,
    runner: Runner | None = None,
) -> BorderMergeOutputs:
    """
    Merge border files into a new file.
    
    Takes one or more border files and makes a new border file from the borders
    in them.
    
    Example: wb_command -border-merge out.border -border first.border -select 1
    -border second.border
    
    This example would take the first border from first.border, followed by all
    borders from second.border, and write these to out.border.
    
    Author: Washington University School of Medicin
    
    Args:
        border_file_out: the output border file.
        border: specify an input border file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderMergeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BORDER_MERGE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-border-merge")
    cargs.append(border_file_out)
    if border is not None:
        cargs.extend([a for c in [s.run(execution) for s in border] for a in c])
    ret = BorderMergeOutputs(
        root=execution.output_file("."),
        border_file_out=execution.output_file(border_file_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BORDER_MERGE_METADATA",
    "BorderMergeBorder",
    "BorderMergeOutputs",
    "BorderMergeSelect",
    "BorderMergeUpTo",
    "border_merge",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_WEIGHTED_STATS_METADATA = Metadata(
    id="05ac317792e4964ce1a97593a366626541fba245.boutiques",
    name="cifti-weighted-stats",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiWeightedStatsSpatialWeights:
    """
    use vertex area and voxel volume as weights.
    """
    opt_left_area_surf_left_surf: InputPathType | None = None
    """use a surface for left vertex areas: the left surface to use, areas are
    in mm^2"""
    opt_right_area_surf_right_surf: InputPathType | None = None
    """use a surface for right vertex areas: the right surface to use, areas are
    in mm^2"""
    opt_cerebellum_area_surf_cerebellum_surf: InputPathType | None = None
    """use a surface for cerebellum vertex areas: the cerebellum surface to use,
    areas are in mm^2"""
    opt_left_area_metric_left_metric: InputPathType | None = None
    """use a metric file for left vertex areas: metric file containing left
    vertex areas"""
    opt_right_area_metric_right_metric: InputPathType | None = None
    """use a metric file for right vertex areas: metric file containing right
    vertex areas"""
    opt_cerebellum_area_metric_cerebellum_metric: InputPathType | None = None
    """use a metric file for cerebellum vertex areas: metric file containing
    cerebellum vertex areas"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-spatial-weights")
        if self.opt_left_area_surf_left_surf is not None:
            cargs.extend([
                "-left-area-surf",
                execution.input_file(self.opt_left_area_surf_left_surf)
            ])
        if self.opt_right_area_surf_right_surf is not None:
            cargs.extend([
                "-right-area-surf",
                execution.input_file(self.opt_right_area_surf_right_surf)
            ])
        if self.opt_cerebellum_area_surf_cerebellum_surf is not None:
            cargs.extend([
                "-cerebellum-area-surf",
                execution.input_file(self.opt_cerebellum_area_surf_cerebellum_surf)
            ])
        if self.opt_left_area_metric_left_metric is not None:
            cargs.extend([
                "-left-area-metric",
                execution.input_file(self.opt_left_area_metric_left_metric)
            ])
        if self.opt_right_area_metric_right_metric is not None:
            cargs.extend([
                "-right-area-metric",
                execution.input_file(self.opt_right_area_metric_right_metric)
            ])
        if self.opt_cerebellum_area_metric_cerebellum_metric is not None:
            cargs.extend([
                "-cerebellum-area-metric",
                execution.input_file(self.opt_cerebellum_area_metric_cerebellum_metric)
            ])
        return cargs


@dataclasses.dataclass
class CiftiWeightedStatsRoi:
    """
    only consider data inside an roi.
    """
    roi_cifti: InputPathType
    """the roi, as a cifti file"""
    opt_match_maps: bool = False
    """each column of input uses the corresponding column from the roi file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-roi")
        cargs.append(execution.input_file(self.roi_cifti))
        if self.opt_match_maps:
            cargs.append("-match-maps")
        return cargs


class CiftiWeightedStatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_weighted_stats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def cifti_weighted_stats(
    cifti_in: InputPathType,
    spatial_weights: CiftiWeightedStatsSpatialWeights | None = None,
    opt_cifti_weights_weight_cifti: InputPathType | None = None,
    opt_column_column: int | None = None,
    roi: CiftiWeightedStatsRoi | None = None,
    opt_mean: bool = False,
    opt_stdev: bool = False,
    opt_sample: bool = False,
    opt_percentile_percent: float | None = None,
    opt_sum: bool = False,
    opt_show_map_name: bool = False,
    runner: Runner | None = None,
) -> CiftiWeightedStatsOutputs:
    """
    Weighted statistics along cifti columns.
    
    If the mapping along column is brain models, for each column of the input,
    the specified operation is done on each surface and across all voxels, and
    the results are printed on separate lines. For other mapping types, the
    operation is done on each column, and one line per map is printed. Exactly
    one of -spatial-weights or -cifti-weights must be specified. Use -column to
    only give output for a single column. If the -roi option is used without
    -match-maps, then each line will contain as many numbers as there are maps
    in the ROI file, separated by tab characters. Exactly one of -mean, -stdev,
    -percentile or -sum must be specified.
    
    Using -sum with -spatial-weights (or with -cifti-weights and a cifti
    containing weights of similar meaning) is equivalent to integrating with
    respect to area and volume. When the input is binary ROIs, this will
    therefore output the area or volume of each ROI.
    
    Author: Washington University School of Medicin
    
    Args:
        cifti_in: the input cifti.
        spatial_weights: use vertex area and voxel volume as weights.
        opt_cifti_weights_weight_cifti: use a cifti file containing weights:\
            the weights to use, as a cifti file.
        opt_column_column: only display output for one column: the column to\
            use (1-based).
        roi: only consider data inside an roi.
        opt_mean: compute weighted mean.
        opt_stdev: compute weighted standard deviation.
        opt_sample: estimate population stdev from the sample.
        opt_percentile_percent: compute weighted percentile: the percentile to\
            find, must be between 0 and 100.
        opt_sum: compute weighted sum.
        opt_show_map_name: print map index and name before each output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiWeightedStatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_WEIGHTED_STATS_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-weighted-stats")
    cargs.append(execution.input_file(cifti_in))
    if spatial_weights is not None:
        cargs.extend(spatial_weights.run(execution))
    if opt_cifti_weights_weight_cifti is not None:
        cargs.extend([
            "-cifti-weights",
            execution.input_file(opt_cifti_weights_weight_cifti)
        ])
    if opt_column_column is not None:
        cargs.extend([
            "-column",
            str(opt_column_column)
        ])
    if roi is not None:
        cargs.extend(roi.run(execution))
    if opt_mean:
        cargs.append("-mean")
    if opt_stdev:
        cargs.append("-stdev")
    if opt_sample:
        cargs.append("-sample")
    if opt_percentile_percent is not None:
        cargs.extend([
            "-percentile",
            str(opt_percentile_percent)
        ])
    if opt_sum:
        cargs.append("-sum")
    if opt_show_map_name:
        cargs.append("-show-map-name")
    ret = CiftiWeightedStatsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_WEIGHTED_STATS_METADATA",
    "CiftiWeightedStatsOutputs",
    "CiftiWeightedStatsRoi",
    "CiftiWeightedStatsSpatialWeights",
    "cifti_weighted_stats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TBSS_3_POSTREG_METADATA = Metadata(
    id="c19a16710795ec146e134573826a707599f9e887.boutiques",
    name="tbss_3_postreg",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class Tbss3PostregOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tbss_3_postreg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def tbss_3_postreg(
    runner: Runner | None = None,
) -> Tbss3PostregOutputs:
    """
    TBSS post-registration processing.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/TBSS/UserGuide#tbss_3_postreg
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Tbss3PostregOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TBSS_3_POSTREG_METADATA)
    cargs = []
    cargs.append("tbss_3_postreg")
    cargs.append("[OPTIONS]")
    ret = Tbss3PostregOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TBSS_3_POSTREG_METADATA",
    "Tbss3PostregOutputs",
    "tbss_3_postreg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_CREATE_DENSE_TIMESERIES_METADATA = Metadata(
    id="5456f1c9282ce73af081351a9260762fc07d7440.boutiques",
    name="cifti-create-dense-timeseries",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiCreateDenseTimeseriesVolume:
    """
    volume component.
    """
    volume_data: InputPathType
    """volume file containing all voxel data for all volume structures"""
    structure_label_volume: InputPathType
    """label volume file containing labels for cifti structures"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-volume")
        cargs.append(execution.input_file(self.volume_data))
        cargs.append(execution.input_file(self.structure_label_volume))
        return cargs


@dataclasses.dataclass
class CiftiCreateDenseTimeseriesLeftMetric:
    """
    metric for left surface.
    """
    metric: InputPathType
    """the metric file"""
    opt_roi_left_roi_metric: InputPathType | None = None
    """roi of vertices to use from left surface: the ROI as a metric file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-left-metric")
        cargs.append(execution.input_file(self.metric))
        if self.opt_roi_left_roi_metric is not None:
            cargs.extend([
                "-roi-left",
                execution.input_file(self.opt_roi_left_roi_metric)
            ])
        return cargs


@dataclasses.dataclass
class CiftiCreateDenseTimeseriesRightMetric:
    """
    metric for left surface.
    """
    metric: InputPathType
    """the metric file"""
    opt_roi_right_roi_metric: InputPathType | None = None
    """roi of vertices to use from right surface: the ROI as a metric file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-right-metric")
        cargs.append(execution.input_file(self.metric))
        if self.opt_roi_right_roi_metric is not None:
            cargs.extend([
                "-roi-right",
                execution.input_file(self.opt_roi_right_roi_metric)
            ])
        return cargs


@dataclasses.dataclass
class CiftiCreateDenseTimeseriesCerebellumMetric:
    """
    metric for the cerebellum.
    """
    metric: InputPathType
    """the metric file"""
    opt_roi_cerebellum_roi_metric: InputPathType | None = None
    """roi of vertices to use from right surface: the ROI as a metric file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-cerebellum-metric")
        cargs.append(execution.input_file(self.metric))
        if self.opt_roi_cerebellum_roi_metric is not None:
            cargs.extend([
                "-roi-cerebellum",
                execution.input_file(self.opt_roi_cerebellum_roi_metric)
            ])
        return cargs


class CiftiCreateDenseTimeseriesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_create_dense_timeseries(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_create_dense_timeseries(
    cifti_out: str,
    volume: CiftiCreateDenseTimeseriesVolume | None = None,
    left_metric: CiftiCreateDenseTimeseriesLeftMetric | None = None,
    right_metric: CiftiCreateDenseTimeseriesRightMetric | None = None,
    cerebellum_metric: CiftiCreateDenseTimeseriesCerebellumMetric | None = None,
    opt_timestep_interval: float | None = None,
    opt_timestart_start: float | None = None,
    opt_unit_unit: str | None = None,
    runner: Runner | None = None,
) -> CiftiCreateDenseTimeseriesOutputs:
    """
    Create a cifti dense timeseries.
    
    All input files must have the same number of columns/subvolumes. Only the
    specified components will be in the output cifti. At least one component
    must be specified.
    
    See -volume-label-import and -volume-help for format details of label volume
    files. The structure-label-volume should have some of the label names from
    this list, all other label names will be ignored:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT
    
    The -unit option accepts these values:
    
    SECOND
    HERTZ
    METER
    RADIAN.
    
    Author: Washington University School of Medicin
    
    Args:
        cifti_out: the output cifti file.
        volume: volume component.
        left_metric: metric for left surface.
        right_metric: metric for left surface.
        cerebellum_metric: metric for the cerebellum.
        opt_timestep_interval: set the timestep: the timestep, in seconds\
            (default 1.0).
        opt_timestart_start: set the start time: the time at the first frame,\
            in seconds (default 0.0).
        opt_unit_unit: use a unit other than time: unit identifier (default\
            SECOND).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiCreateDenseTimeseriesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_CREATE_DENSE_TIMESERIES_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-create-dense-timeseries")
    cargs.append(cifti_out)
    if volume is not None:
        cargs.extend(volume.run(execution))
    if left_metric is not None:
        cargs.extend(left_metric.run(execution))
    if right_metric is not None:
        cargs.extend(right_metric.run(execution))
    if cerebellum_metric is not None:
        cargs.extend(cerebellum_metric.run(execution))
    if opt_timestep_interval is not None:
        cargs.extend([
            "-timestep",
            str(opt_timestep_interval)
        ])
    if opt_timestart_start is not None:
        cargs.extend([
            "-timestart",
            str(opt_timestart_start)
        ])
    if opt_unit_unit is not None:
        cargs.extend([
            "-unit",
            opt_unit_unit
        ])
    ret = CiftiCreateDenseTimeseriesOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(cifti_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_CREATE_DENSE_TIMESERIES_METADATA",
    "CiftiCreateDenseTimeseriesCerebellumMetric",
    "CiftiCreateDenseTimeseriesLeftMetric",
    "CiftiCreateDenseTimeseriesOutputs",
    "CiftiCreateDenseTimeseriesRightMetric",
    "CiftiCreateDenseTimeseriesVolume",
    "cifti_create_dense_timeseries",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__INSTALL_RSFMRI_MOTION_GROUP_DEMO_METADATA = Metadata(
    id="2bc3003582dfbea0e9f77aa8215552906ad0cb34.boutiques",
    name="@Install_RSFMRI_Motion_Group_Demo",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VInstallRsfmriMotionGroupDemoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__install_rsfmri_motion_group_demo(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    afni_demo_dir: OutputPathType
    """Directory where the demo data and scripts are set up."""


def v__install_rsfmri_motion_group_demo(
    output_dir: str,
    runner: Runner | None = None,
) -> VInstallRsfmriMotionGroupDemoOutputs:
    """
    Installs and sets up an AFNI InstaCorr demo archive, based on 190 Cambridge
    subjects from FCON_1000.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@Install_RSFMRI_Motion_Group_Demo.html
    
    Args:
        output_dir: Directory where the AFNI_Demo_Motion_Groups will be set up.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VInstallRsfmriMotionGroupDemoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__INSTALL_RSFMRI_MOTION_GROUP_DEMO_METADATA)
    cargs = []
    cargs.append("@Install_RSFMRI_Motion_Group_Demo")
    cargs.append(output_dir)
    ret = VInstallRsfmriMotionGroupDemoOutputs(
        root=execution.output_file("."),
        afni_demo_dir=execution.output_file(output_dir + "/AFNI_Demo_Motion_Groups"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VInstallRsfmriMotionGroupDemoOutputs",
    "V__INSTALL_RSFMRI_MOTION_GROUP_DEMO_METADATA",
    "v__install_rsfmri_motion_group_demo",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TFITTER_METADATA = Metadata(
    id="ebe3239eb8a2ffc8eab35fc3eaf4d336d88af085.boutiques",
    name="3dTfitter",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTfitterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_tfitter(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_prefix: OutputPathType
    """Output dataset for LHS parameters."""
    fitted_time_series: OutputPathType
    """Output fitted time series dataset."""
    error_sums: OutputPathType
    """Output error sums dataset."""


def v_3d_tfitter(
    runner: Runner | None = None,
) -> V3dTfitterOutputs:
    """
    * At each voxel, assembles and solves a set of linear equations.
    ++ The matrix at each voxel may be the same or may be different.
    ++ This flexibility (for voxel-wise regressors) is one feature
    that makes 3dTfitter different from 3dDeconvolve.
    ++ Another distinguishing feature is that 3dTfitter allows for
    L2, L1, and L2+L1 (LASSO) regression solvers, and allows you
    to impose sign constraints on the solution parameters.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dTfitter.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTfitterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TFITTER_METADATA)
    cargs = []
    cargs.append("3dTfitter")
    cargs.append("[ARGS]")
    ret = V3dTfitterOutputs(
        root=execution.output_file("."),
        output_prefix=execution.output_file("[PREFIX].nii.gz"),
        fitted_time_series=execution.output_file("[FITTS].nii.gz"),
        error_sums=execution.output_file("[ERRSUM].nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTfitterOutputs",
    "V_3D_TFITTER_METADATA",
    "v_3d_tfitter",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PVMFIT_METADATA = Metadata(
    id="5a8e526ca13ed2dae6d5a4c185e4c029ff2b448b.boutiques",
    name="pvmfit",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class PvmfitOutputs(typing.NamedTuple):
    """
    Output object returned when calling `pvmfit(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """Main output file"""
    bic_file: OutputPathType | None
    """Optional: Saved BIC (Bayesian Information Criterion) for certain
    models"""


def pvmfit(
    data_file: InputPathType,
    mask_file: InputPathType,
    bvec_file: InputPathType,
    bval_file: InputPathType,
    output_basename: str | None = "pvm",
    number_of_fibres: float | None = 1,
    model_type: int | None = None,
    fit_all_models: bool = False,
    constrained_nonlinear: bool = False,
    constrained_nonlinear_f: bool = False,
    grid_search: bool = False,
    include_noise_floor: bool = False,
    save_bic: bool = False,
    verbose: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> PvmfitOutputs:
    """
    Fits diffusion models to multishell DWI data.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/
    
    Args:
        data_file: Data file.
        mask_file: Mask file.
        bvec_file: B vectors file.
        bval_file: B values file.
        output_basename: Output basename - default='pvm'.
        number_of_fibres: Number of fibres to fit - default=1.
        model_type: Model type: 1 for Ball-Sticks (single-shell), 2 for\
            Ball-Sticks (multi-shells), 4 for Ball-Binghams.
        fit_all_models: Fit all models from 1 up to N fibres and choose the\
            best using BIC.
        constrained_nonlinear: Model1: Apply constrained nonlinear optimization\
            on the diffusivity, volume fractions and their sum.
        constrained_nonlinear_f: Model1: Apply constrained nonlinear\
            optimization on the diffusivity, volume fractions and their sum. Return\
            n fanning angle estimates, using the Hessian of the cost function.
        grid_search: Use grid search (on the fanning eigenvalues). Default=off.
        include_noise_floor: Include noise floor parameter in the model.
        save_bic: Save BIC for certain models.
        verbose: Switch on diagnostic messages.
        help_: Display help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PvmfitOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PVMFIT_METADATA)
    cargs = []
    cargs.append("pvmfit")
    cargs.append("-k")
    cargs.append(execution.input_file(data_file))
    cargs.append("-m")
    cargs.append(execution.input_file(mask_file))
    cargs.append("-r")
    cargs.append(execution.input_file(bvec_file))
    cargs.append("-b")
    cargs.append(execution.input_file(bval_file))
    if output_basename is not None:
        cargs.extend([
            "-o",
            output_basename
        ])
    if number_of_fibres is not None:
        cargs.extend([
            "-n",
            str(number_of_fibres)
        ])
    if model_type is not None:
        cargs.extend([
            "--model",
            str(model_type)
        ])
    if fit_all_models:
        cargs.append("--all")
    if constrained_nonlinear:
        cargs.append("--cnonlinear")
    if constrained_nonlinear_f:
        cargs.append("--cnonlinear_F")
    if grid_search:
        cargs.append("--gridsearch")
    if include_noise_floor:
        cargs.append("--f0")
    if save_bic:
        cargs.append("--BIC")
    if verbose:
        cargs.append("-V")
    if help_:
        cargs.append("-h")
    ret = PvmfitOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_basename + ".nii.gz") if (output_basename is not None) else None,
        bic_file=execution.output_file(output_basename + "_BIC.nii.gz") if (output_basename is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PVMFIT_METADATA",
    "PvmfitOutputs",
    "pvmfit",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__INSTALL_AFNI_RETINO_DEMO_METADATA = Metadata(
    id="1899f0af35d9fd5f3da22643ad090264cbb802f7.boutiques",
    name="@Install_AfniRetinoDemo",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VInstallAfniRetinoDemoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__install_afni_retino_demo(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    retino_demo_dir: OutputPathType
    """Output directory where the demo files are installed"""


def v__install_afni_retino_demo(
    output_dir: str,
    runner: Runner | None = None,
) -> VInstallAfniRetinoDemoOutputs:
    """
    Installs and runs demo script for the retinotopy pipeline demo.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@Install_AfniRetinoDemo.html
    
    Args:
        output_dir: Output directory where the demo will be installed and run.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VInstallAfniRetinoDemoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__INSTALL_AFNI_RETINO_DEMO_METADATA)
    cargs = []
    cargs.append("@Install_AfniRetinoDemo")
    cargs.append(output_dir)
    ret = VInstallAfniRetinoDemoOutputs(
        root=execution.output_file("."),
        retino_demo_dir=execution.output_file(output_dir + "/AfniRetinoDemo"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VInstallAfniRetinoDemoOutputs",
    "V__INSTALL_AFNI_RETINO_DEMO_METADATA",
    "v__install_afni_retino_demo",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__FLOAT_FIX_METADATA = Metadata(
    id="38e670c67a4f335c69819469b6c1f05a91fb5331.boutiques",
    name="@float_fix",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VFloatFixOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__float_fix(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__float_fix(
    input_files: list[InputPathType],
    runner: Runner | None = None,
) -> VFloatFixOutputs:
    """
    Check whether the input files have any IEEE floating point numbers for illegal
    values: infinities and not-a-number (NaN) values.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@float_fix.html
    
    Args:
        input_files: Input files to be checked for illegal IEEE floating point\
            values. Wildcards can be used, but filenames must end with .HEAD.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VFloatFixOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__FLOAT_FIX_METADATA)
    cargs = []
    cargs.append("@float_fix")
    cargs.extend([execution.input_file(f) for f in input_files])
    ret = VFloatFixOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VFloatFixOutputs",
    "V__FLOAT_FIX_METADATA",
    "v__float_fix",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__TO_MNI_QWARPAR_METADATA = Metadata(
    id="131654d97cc05cd5094369e35dc295516e4f329d.boutiques",
    name="@toMNI_Qwarpar",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VToMniQwarparOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__to_mni_qwarpar(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output dataset created after processing."""


def v__to_mni_qwarpar(
    runner: Runner | None = None,
) -> VToMniQwarparOutputs:
    """
    Transforms datasets to MNI space, then collectively re-transforms them to
    produce a refined average.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@toMNI_Qwarpar.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VToMniQwarparOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__TO_MNI_QWARPAR_METADATA)
    cargs = []
    cargs.append("@toMNI_Qwarpar")
    ret = VToMniQwarparOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("*_uni+tlrc.HEAD"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VToMniQwarparOutputs",
    "V__TO_MNI_QWARPAR_METADATA",
    "v__to_mni_qwarpar",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_FALSE_CORRELATION_METADATA = Metadata(
    id="3baaab7ec58d4ecf17080e5a45547fdfdb634af1.boutiques",
    name="cifti-false-correlation",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiFalseCorrelationLeftSurface:
    """
    specify the left surface to use.
    """
    surface: InputPathType
    """the left surface file"""
    opt_dump_text_text_out: str | None = None
    """dump the raw measures used to a text file: the output text file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-left-surface")
        cargs.append(execution.input_file(self.surface))
        if self.opt_dump_text_text_out is not None:
            cargs.extend([
                "-dump-text",
                self.opt_dump_text_text_out
            ])
        return cargs


@dataclasses.dataclass
class CiftiFalseCorrelationRightSurface:
    """
    specify the right surface to use.
    """
    surface: InputPathType
    """the right surface file"""
    opt_dump_text_text_out: str | None = None
    """dump the raw measures used to a text file: the output text file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-right-surface")
        cargs.append(execution.input_file(self.surface))
        if self.opt_dump_text_text_out is not None:
            cargs.extend([
                "-dump-text",
                self.opt_dump_text_text_out
            ])
        return cargs


@dataclasses.dataclass
class CiftiFalseCorrelationCerebellumSurface:
    """
    specify the cerebellum surface to use.
    """
    surface: InputPathType
    """the cerebellum surface file"""
    opt_dump_text_text_out: str | None = None
    """dump the raw measures used to a text file: the output text file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-cerebellum-surface")
        cargs.append(execution.input_file(self.surface))
        if self.opt_dump_text_text_out is not None:
            cargs.extend([
                "-dump-text",
                self.opt_dump_text_text_out
            ])
        return cargs


class CiftiFalseCorrelationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_false_correlation(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti dscalar file"""


def cifti_false_correlation(
    cifti_in: InputPathType,
    v_3d_dist: float,
    geo_outer: float,
    geo_inner: float,
    cifti_out: str,
    left_surface: CiftiFalseCorrelationLeftSurface | None = None,
    right_surface: CiftiFalseCorrelationRightSurface | None = None,
    cerebellum_surface: CiftiFalseCorrelationCerebellumSurface | None = None,
    runner: Runner | None = None,
) -> CiftiFalseCorrelationOutputs:
    """
    Compare correlation locally and across/through sulci/gyri.
    
    For each vertex, compute the average correlation within a range of geodesic
    distances that don't cross a sulcus/gyrus, and the correlation to the
    closest vertex crossing a sulcus/gyrus. A vertex is considered to cross a
    sulcus/gyrus if the 3D distance is less than a third of the geodesic
    distance. The output file contains the ratio between these correlations, and
    some additional maps to help explain the ratio.
    
    Author: Washington University School of Medicin
    
    Args:
        cifti_in: the cifti file to use for correlation.
        v_3d_dist: maximum 3D distance to check around each vertex.
        geo_outer: maximum geodesic distance to use for neighboring correlation.
        geo_inner: minimum geodesic distance to use for neighboring correlation.
        cifti_out: the output cifti dscalar file.
        left_surface: specify the left surface to use.
        right_surface: specify the right surface to use.
        cerebellum_surface: specify the cerebellum surface to use.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiFalseCorrelationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_FALSE_CORRELATION_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-false-correlation")
    cargs.append(execution.input_file(cifti_in))
    cargs.append(str(v_3d_dist))
    cargs.append(str(geo_outer))
    cargs.append(str(geo_inner))
    cargs.append(cifti_out)
    if left_surface is not None:
        cargs.extend(left_surface.run(execution))
    if right_surface is not None:
        cargs.extend(right_surface.run(execution))
    if cerebellum_surface is not None:
        cargs.extend(cerebellum_surface.run(execution))
    ret = CiftiFalseCorrelationOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(cifti_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_FALSE_CORRELATION_METADATA",
    "CiftiFalseCorrelationCerebellumSurface",
    "CiftiFalseCorrelationLeftSurface",
    "CiftiFalseCorrelationOutputs",
    "CiftiFalseCorrelationRightSurface",
    "cifti_false_correlation",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FAT_MAT2D_PLOT_PY_METADATA = Metadata(
    id="909f20f2f2c0d68f80b7d1baec761751f15c9fc6.boutiques",
    name="fat_mat2d_plot.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FatMat2dPlotPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fat_mat2d_plot_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_files: OutputPathType | None
    """Individual image files of matrices; these can contain colorbars, as
    well."""


def fat_mat2d_plot_py(
    input_file: InputPathType,
    matrices: list[str] | None = None,
    prefix: str | None = None,
    file_type: str | None = None,
    dpi: float | None = None,
    min_colorbar: float | None = None,
    max_colorbar: float | None = None,
    fs_xticks: float | None = None,
    fs_yticks: float | None = None,
    fs_title: float | None = None,
    fs_cbar: float | None = None,
    cbar_n_intervals: float | None = None,
    cbar: str | None = None,
    cbar_width_perc: float | None = None,
    no_colorbar: bool = False,
    figsize_x: float | None = None,
    figsize_y: float | None = None,
    hold_image: bool = False,
    tight_layout: bool = False,
    xticks_off: bool = False,
    yticks_off: bool = False,
    version: bool = False,
    date: bool = False,
    help_: bool = False,
    help_view: bool = False,
    runner: Runner | None = None,
) -> FatMat2dPlotPyOutputs:
    """
    Plots simple matrices output from 3dNetCorr (*.netcc) and 3dTrackID (*.grid).
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/fat_mat2d_plot.py.html
    
    Args:
        input_file: Name of *.netcc or *.grid file with matrices to be plotted.
        matrices: List of matrices to be plotted, identified by their parameter\
            name. If no list is provided, then all matrices in the input file will\
            be plotted.
        prefix: Output basename for image(s). Note that this can include path\
            information, but the name of each matrix and the file extension will be\
            appended to it.
        file_type: Filetype, given as extension (e.g., png, jpg). Available\
            filetypes depend slightly on your OS and setup.
        dpi: Spatial resolution (dots per inch) of output images.
        min_colorbar: Minimum value of the colorbar.
        max_colorbar: Maximum value of the colorbar.
        fs_xticks: Font size of ticks along the x-axis.
        fs_yticks: Font size of ticks along the y-axis.
        fs_title: Font size of the title.
        fs_cbar: Font size of the colorbar.
        cbar_n_intervals: Number of intervals on colorbars for enumeration\
            purposes. This controls how many numbers appear along the colorbar\
            (which would be NI +1).
        cbar: Name of the colorbar to use. The available colormaps can be found\
            online.
        cbar_width_perc: Width of the colorbar as a percentage of the image.
        no_colorbar: Disable the colorbar in the image.
        figsize_x: Width of the created image in inches.
        figsize_y: Height of the created image in inches.
        hold_image: In addition to saving an image file, open the image and\
            keep displaying it until a key is pressed in the terminal.
        tight_layout: Use matplotlib's tight layout functionality in arranging\
            the plot.
        xticks_off: Don't display labels along the x-axis.
        yticks_off: Don't display labels along the y-axis.
        version: Display the version number of the program.
        date: Display the release/editing date of the current version.
        help_: Display help in the terminal.
        help_view: Display help in a separate text editor.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FatMat2dPlotPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FAT_MAT2D_PLOT_PY_METADATA)
    cargs = []
    cargs.append("fat_mat2d_plot.py")
    cargs.append(execution.input_file(input_file))
    if matrices is not None:
        cargs.extend(matrices)
    if prefix is not None:
        cargs.append(prefix)
    if file_type is not None:
        cargs.append(file_type)
    if dpi is not None:
        cargs.append(str(dpi))
    if min_colorbar is not None:
        cargs.append(str(min_colorbar))
    if max_colorbar is not None:
        cargs.append(str(max_colorbar))
    if fs_xticks is not None:
        cargs.append(str(fs_xticks))
    if fs_yticks is not None:
        cargs.append(str(fs_yticks))
    if fs_title is not None:
        cargs.append(str(fs_title))
    if fs_cbar is not None:
        cargs.append(str(fs_cbar))
    if cbar_n_intervals is not None:
        cargs.append(str(cbar_n_intervals))
    if cbar is not None:
        cargs.append(cbar)
    if cbar_width_perc is not None:
        cargs.append(str(cbar_width_perc))
    if no_colorbar:
        cargs.append("-cbar_off")
    if figsize_x is not None:
        cargs.append(str(figsize_x))
    if figsize_y is not None:
        cargs.append(str(figsize_y))
    if hold_image:
        cargs.append("-hold_image")
    if tight_layout:
        cargs.append("-tight_layout")
    if xticks_off:
        cargs.append("-xticks_off")
    if yticks_off:
        cargs.append("-yticks_off")
    if version:
        cargs.append("-ver")
    if date:
        cargs.append("-date")
    if help_:
        cargs.append("-help")
    if help_view:
        cargs.append("-hview")
    ret = FatMat2dPlotPyOutputs(
        root=execution.output_file("."),
        output_files=execution.output_file(prefix + "_[MATRIX_NAME]." + file_type) if (prefix is not None and file_type is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FAT_MAT2D_PLOT_PY_METADATA",
    "FatMat2dPlotPyOutputs",
    "fat_mat2d_plot_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FROM3D_METADATA = Metadata(
    id="864634840f0f6786ab607ffcdd49ef22b22f25d8.boutiques",
    name="from3d",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class From3dOutputs(typing.NamedTuple):
    """
    Output object returned when calling `from3d(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    extracted_images: OutputPathType
    """Extracted 2D images from the 3D dataset"""


def from3d(
    input_: InputPathType,
    prefix: str,
    verbose: bool = False,
    nsize_: bool = False,
    raw: bool = False,
    float_: bool = False,
    zfirst: float | None = None,
    zlast: float | None = None,
    tfirst: float | None = None,
    tlast: float | None = None,
    runner: Runner | None = None,
) -> From3dOutputs:
    """
    Extract 2D image files from a 3D AFNI dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/from3d.html
    
    Args:
        input_: Read 3D dataset from file 'fname'.
        prefix: Write 2D images using prefix 'rname'.
        verbose: Print out verbose information during the run.
        nsize_: Adjust size of 2D data file to be NxN, by padding with zeros,\
            where N is a power of 2.
        raw: Write images in 'raw' format (just the data bytes). There will be\
            no header information saying what the image dimensions are.
        float_: Write images as floats, no matter what they are in the dataset\
            itself.
        zfirst: Set 'num' = number of first z slice to be extracted (default =\
            1).
        zlast: Set 'num' = number of last z slice to be extracted (default =\
            largest).
        tfirst: Set 'num' = number of first time slice to be extracted (default\
            = 1).
        tlast: Set 'num' = number of last time slice to be extracted (default =\
            largest).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `From3dOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FROM3D_METADATA)
    cargs = []
    cargs.append("from3d")
    if verbose:
        cargs.append("-v")
    if nsize_:
        cargs.append("-nsize")
    if raw:
        cargs.append("-raw")
    if float_:
        cargs.append("-float")
    if zfirst is not None:
        cargs.extend([
            "-zfirst",
            str(zfirst)
        ])
    if zlast is not None:
        cargs.extend([
            "-zlast",
            str(zlast)
        ])
    if tfirst is not None:
        cargs.extend([
            "-tfirst",
            str(tfirst)
        ])
    if tlast is not None:
        cargs.extend([
            "-tlast",
            str(tlast)
        ])
    cargs.append("-input")
    cargs.extend([
        "-input",
        execution.input_file(input_)
    ])
    cargs.append("-prefix")
    cargs.extend([
        "-prefix",
        prefix
    ])
    ret = From3dOutputs(
        root=execution.output_file("."),
        extracted_images=execution.output_file(prefix + "*.img"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FROM3D_METADATA",
    "From3dOutputs",
    "from3d",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DROTATE_METADATA = Metadata(
    id="1e89e84da477d0e0cc5664a7752ca7af732ad786.boutiques",
    name="3drotate",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3drotateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3drotate(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_head: OutputPathType
    """Output dataset header file"""
    out_brick: OutputPathType
    """Output dataset brick file"""


def v_3drotate(
    dataset: InputPathType,
    runner: Runner | None = None,
) -> V3drotateOutputs:
    """
    Rotates and/or translates all bricks from an AFNI dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3drotate.html
    
    Args:
        dataset: Input AFNI dataset, may contain a sub-brick selector list.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3drotateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DROTATE_METADATA)
    cargs = []
    cargs.append("3drotate")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(dataset))
    ret = V3drotateOutputs(
        root=execution.output_file("."),
        out_head=execution.output_file("[PREFIX]+orig.HEAD"),
        out_brick=execution.output_file("[PREFIX]+orig.BRIK"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3drotateOutputs",
    "V_3DROTATE_METADATA",
    "v_3drotate",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LABEL_EXPORT_TABLE_METADATA = Metadata(
    id="e6ffb015df82a0d94657f22347b6a146708f08dc.boutiques",
    name="label-export-table",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class LabelExportTableOutputs(typing.NamedTuple):
    """
    Output object returned when calling `label_export_table(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def label_export_table(
    label_in: InputPathType,
    table_out: str,
    runner: Runner | None = None,
) -> LabelExportTableOutputs:
    """
    Export label table from gifti as text.
    
    Takes the label table from the gifti label file, and writes it to a text
    format matching what is expected by -metric-label-import.
    
    Author: Washington University School of Medicin
    
    Args:
        label_in: the input label file.
        table_out: output - the output text file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelExportTableOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABEL_EXPORT_TABLE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-label-export-table")
    cargs.append(execution.input_file(label_in))
    cargs.append(table_out)
    ret = LabelExportTableOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LABEL_EXPORT_TABLE_METADATA",
    "LabelExportTableOutputs",
    "label_export_table",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__ROI_DECLUSTER_METADATA = Metadata(
    id="9f3d049396f0d326df99a0da9701f22c54f456e3.boutiques",
    name="@ROI_decluster",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VRoiDeclusterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__roi_decluster(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Final output dataset"""


def v__roi_decluster(
    runner: Runner | None = None,
) -> VRoiDeclusterOutputs:
    """
    Script to remove small clusters or standalone voxels from an ROI/atlas dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@ROI_decluster.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VRoiDeclusterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__ROI_DECLUSTER_METADATA)
    cargs = []
    cargs.append("@ROI_decluster")
    cargs.append("-input")
    cargs.append("<input>")
    cargs.append("-outdir")
    cargs.append("<outdir>")
    cargs.append("-prefix")
    cargs.append("<prefix>")
    cargs.append("-nvox_thresh")
    cargs.append("<nvox_thresh>")
    cargs.append("-frac_thresh")
    cargs.append("<frac_thresh>")
    cargs.append("-NN")
    cargs.append("<NN>")
    ret = VRoiDeclusterOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("[PREFIX].nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VRoiDeclusterOutputs",
    "V__ROI_DECLUSTER_METADATA",
    "v__roi_decluster",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__GLOBAL_PARSE_METADATA = Metadata(
    id="5342cfbbbd394a241af39de5bbec7346f14262c0.boutiques",
    name="@global_parse",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VGlobalParseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__global_parse(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__global_parse(
    program_name: str,
    options: list[str] | None = None,
    runner: Runner | None = None,
) -> VGlobalParseOutputs:
    """
    Script to parse global help options for other scripts.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@global_parse.html
    
    Args:
        program_name: The name of the program whose help output is sought.
        options: Options to be passed to the specified program.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VGlobalParseOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__GLOBAL_PARSE_METADATA)
    cargs = []
    cargs.append("global_parse")
    cargs.append(program_name)
    if options is not None:
        cargs.extend(options)
    ret = VGlobalParseOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VGlobalParseOutputs",
    "V__GLOBAL_PARSE_METADATA",
    "v__global_parse",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FILM_GLS_METADATA = Metadata(
    id="13325ae4e46130f047acd6b312c79334f8766b7b.boutiques",
    name="film_gls",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FilmGlsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `film_gls(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    prewhitened_data: OutputPathType
    """Prewhitened data output"""
    average_design_matrix: OutputPathType
    """Average design matrix output"""
    results_data: OutputPathType
    """Results output"""


def film_gls(
    infile: InputPathType,
    ac_flag: bool = False,
    threshold: float | None = None,
    ar_flag: bool = False,
    noest_flag: bool = False,
    output_pw_flag: bool = False,
    pava_flag: bool = False,
    sa_flag: bool = False,
    verbose_flag: bool = False,
    results_dir: str | None = None,
    mode: str | None = None,
    input_surface: InputPathType | None = None,
    mean_func_file: InputPathType | None = None,
    min_timepoint_file: InputPathType | None = None,
    paradigm_file: InputPathType | None = None,
    t_contrasts_file: InputPathType | None = None,
    f_contrasts_file: InputPathType | None = None,
    epith: float | None = None,
    ms: float | None = None,
    tukey: float | None = None,
    mt: float | None = None,
    ven: list[str] | None = None,
    vef: list[InputPathType] | None = None,
    runner: Runner | None = None,
) -> FilmGlsOutputs:
    """
    General Linear Model fitting with autocorrelation in FMRI.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FILM
    
    Args:
        infile: Input data file (NIFTI for volumetric, GIFTI for surface).
        ac_flag: Perform autocorrelation estimation only.
        threshold: Initial threshold to apply to input data.
        ar_flag: Fits autoregressive model - default is to use tukey with\
            M=sqrt(numvols).
        noest_flag: Do not estimate autocorrelations.
        output_pw_flag: Output prewhitened data and average design matrix.
        pava_flag: Estimates autocorrelation using PAVA - default is to use\
            tukey with M=sqrt(numvols).
        sa_flag: Smooths autocorrelation estimates.
        verbose_flag: Outputs full data.
        results_dir: Directory name to store results in, default is results.
        mode: Analysis mode, options are volumetric (default) or surface.\
            Caution: surface-based functionality is still BETA.
        input_surface: Input surface for autocorrelation smoothing in\
            surface-based analyses.
        mean_func_file: Re-estimate mean_func baseline - for use with perfusion\
            subtraction.
        min_timepoint_file: Minimum timepoint file.
        paradigm_file: Paradigm file.
        t_contrasts_file: T-contrasts file.
        f_contrasts_file: F-contrasts file.
        epith: SUSAN brightness threshold for volumetric analysis/smoothing\
            sigma for surface analysis.
        ms: SUSAN mask size for volumetric analysis/smoothing extent for\
            surface analysis.
        tukey: Uses tukey window to estimate autocorrelation with window size\
            num - default is to use tukey with M=sqrt(numvols).
        mt: Uses multitapering with slepian tapers and num is the\
            time-bandwidth product - default is to use tukey with M=sqrt(numvols).
        ven: List of numbers indicating voxelwise EVs position in the design\
            matrix (list order corresponds to files in vxf option). Caution BETA\
            option, only use with volumetric analysis.
        vef: List of 4D images containing voxelwise EVs (list order corresponds\
            to numbers in vxl option). Caution BETA option, only use with\
            volumetric analysis.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FilmGlsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FILM_GLS_METADATA)
    cargs = []
    cargs.append("film_gls")
    cargs.append(execution.input_file(infile))
    if ac_flag:
        cargs.append("--ac")
    if threshold is not None:
        cargs.extend([
            "--thr",
            str(threshold)
        ])
    if ar_flag:
        cargs.append("--ar")
    if noest_flag:
        cargs.append("--noest")
    if output_pw_flag:
        cargs.append("--outputPWdata")
    if pava_flag:
        cargs.append("--pava")
    if sa_flag:
        cargs.append("--sa")
    if verbose_flag:
        cargs.append("-v")
    if results_dir is not None:
        cargs.extend([
            "--rn",
            results_dir
        ])
    if mode is not None:
        cargs.extend([
            "--mode",
            mode
        ])
    if input_surface is not None:
        cargs.extend([
            "--in2",
            execution.input_file(input_surface)
        ])
    if mean_func_file is not None:
        cargs.extend([
            "--mf",
            execution.input_file(mean_func_file)
        ])
    if min_timepoint_file is not None:
        cargs.extend([
            "--mft",
            execution.input_file(min_timepoint_file)
        ])
    if paradigm_file is not None:
        cargs.extend([
            "--pd",
            execution.input_file(paradigm_file)
        ])
    if t_contrasts_file is not None:
        cargs.extend([
            "--con",
            execution.input_file(t_contrasts_file)
        ])
    if f_contrasts_file is not None:
        cargs.extend([
            "--fcon",
            execution.input_file(f_contrasts_file)
        ])
    if epith is not None:
        cargs.extend([
            "--epith",
            str(epith)
        ])
    if ms is not None:
        cargs.extend([
            "--ms",
            str(ms)
        ])
    if tukey is not None:
        cargs.extend([
            "--tukey",
            str(tukey)
        ])
    if mt is not None:
        cargs.extend([
            "--mt",
            str(mt)
        ])
    if ven is not None:
        cargs.extend([
            "--ven",
            *ven
        ])
    if vef is not None:
        cargs.extend([
            "--vef",
            *[execution.input_file(f) for f in vef]
        ])
    ret = FilmGlsOutputs(
        root=execution.output_file("."),
        prewhitened_data=execution.output_file("[rn]/prewhitened_data.nii.gz"),
        average_design_matrix=execution.output_file("[rn]/average_design_matrix.txt"),
        results_data=execution.output_file("[rn]/results.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FILM_GLS_METADATA",
    "FilmGlsOutputs",
    "film_gls",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__SNAPSHOT_VOLREG_METADATA = Metadata(
    id="e41cf6ba6d044ca81ae9c6d2ad2f6e1d5280c6d3.boutiques",
    name="@snapshot_volreg",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VSnapshotVolregOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__snapshot_volreg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_jpeg: OutputPathType | None
    """JPEG image showing the edges of the EPI dataset overlayed on the
    anatomical dataset"""


def v__snapshot_volreg(
    anatdataset: InputPathType,
    epidataset: InputPathType,
    jname: str | None = None,
    xdisplay: str | None = None,
    runner: Runner | None = None,
) -> VSnapshotVolregOutputs:
    """
    Create a JPEG image showing the edges of an EPI dataset overlayed on an
    anatomical dataset to judge 3D registration quality.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@snapshot_volreg.html
    
    Args:
        anatdataset: Anatomical dataset file.
        epidataset: EPI dataset file.
        jname: Name for the output JPEG file.
        xdisplay: Display number of an already running Xvfb instance.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VSnapshotVolregOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__SNAPSHOT_VOLREG_METADATA)
    cargs = []
    cargs.append("@snapshot_volreg")
    cargs.append(execution.input_file(anatdataset))
    cargs.append(execution.input_file(epidataset))
    if jname is not None:
        cargs.append(jname)
    if xdisplay is not None:
        cargs.append(xdisplay)
    ret = VSnapshotVolregOutputs(
        root=execution.output_file("."),
        output_jpeg=execution.output_file(jname + ".jpg") if (jname is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VSnapshotVolregOutputs",
    "V__SNAPSHOT_VOLREG_METADATA",
    "v__snapshot_volreg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CONCAT_BVARS_METADATA = Metadata(
    id="6a9bf9f25c132f92894f26ddadc2707ebb8f44eb.boutiques",
    name="concat_bvars",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class ConcatBvarsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `concat_bvars(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Concatenated output .bvars file"""


def concat_bvars(
    output_bvars: InputPathType,
    runner: Runner | None = None,
) -> ConcatBvarsOutputs:
    """
    Concatenate multiple .bvars files into a single .bvars file.
    
    Author: Unknown
    
    Args:
        output_bvars: Output .bvars file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConcatBvarsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONCAT_BVARS_METADATA)
    cargs = []
    cargs.append("concat_bvars")
    cargs.append(execution.input_file(output_bvars))
    cargs.append("[INPUT_BVARS...]")
    ret = ConcatBvarsOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(pathlib.Path(output_bvars).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CONCAT_BVARS_METADATA",
    "ConcatBvarsOutputs",
    "concat_bvars",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1D_NLFIT_METADATA = Metadata(
    id="2b9be7d506110a346f2427566552f2ef8767ba95.boutiques",
    name="1dNLfit",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dNlfitOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1d_nlfit(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    fit_results: OutputPathType
    """Results (fitted time series models) are written to stdout. Should be
    saved by '>' redirection."""


def v_1d_nlfit(
    expression: str,
    independent_variable: str,
    parameters: list[str],
    dependent_data: InputPathType,
    method: int | None = None,
    runner: Runner | None = None,
) -> V1dNlfitOutputs:
    """
    Program to fit a model to a vector of data. The model is given by a symbolic
    expression, with parameters to be estimated.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/1dNLfit.html
    
    Args:
        expression: The expression for the fit. It must contain one symbol from\
            'a' to 'z' which is marked as the independent variable by option\
            '-indvar', and at least one more symbol which is a parameter to be\
            estimated.
        independent_variable: Indicates which variable in '-expr' is the\
            independent variable. All other symbols are parameters, which are\
            either fixed (constants) or variables to be estimated. Read the values\
            of the independent variable from 1D file.
        parameters: Set fixed value or estimating range for a particular\
            symbol. For a fixed value, it takes the form 'a=3.14'. For an estimated\
            parameter, it takes the form 'q=-sqrt(2):sqrt(2)'. All symbols in\
            '-expr' must have a corresponding '-param' option, EXCEPT for the\
            '-indvar' symbol.
        dependent_data: Read the values of the dependent variable (to be fitted\
            to '-expr') from 1D file. The file must have the same number of rows as\
            the '-indvar' file.
        method: Set the method for fitting: '1' for L1, '2' for L2 (default is\
            L2).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dNlfitOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1D_NLFIT_METADATA)
    cargs = []
    cargs.append("1dNLfit")
    cargs.extend([
        "-expr",
        expression
    ])
    cargs.extend([
        "-indvar",
        independent_variable
    ])
    cargs.extend([
        "-param",
        *parameters
    ])
    cargs.extend([
        "-depdata",
        execution.input_file(dependent_data)
    ])
    if method is not None:
        cargs.extend([
            "-meth",
            str(method)
        ])
    ret = V1dNlfitOutputs(
        root=execution.output_file("."),
        fit_results=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dNlfitOutputs",
    "V_1D_NLFIT_METADATA",
    "v_1d_nlfit",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__FS_ROI_LABEL_METADATA = Metadata(
    id="bb0f29897218abed7c1d1903fa1a1efea589bbc6.boutiques",
    name="@FS_roi_label",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VFsRoiLabelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__fs_roi_label(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__fs_roi_label(
    label_int: float | None = None,
    lab_flag: float | None = None,
    rank_int: float | None = None,
    rankmap_file: InputPathType | None = None,
    name: str | None = None,
    labeltable_file: InputPathType | None = None,
    surf_annot_cmap: InputPathType | None = None,
    slab_int: float | None = None,
    sname_name: str | None = None,
    runner: Runner | None = None,
) -> VFsRoiLabelOutputs:
    """
    Tool to get labels associated with FreeSurfer's parcellation and annotation
    files.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@FS_roi_label.html
    
    Args:
        label_int: Integer labeled area in FreeSurfer's parcellation.
        lab_flag: Return the name of an integer labeled area in FreeSurfer's\
            parcellation.
        rank_int: Return the name of ranked integer labeled area from the\
            output of 3dRank or 3dmerge -1rank.
        rankmap_file: Path to the rank map file.
        name: Return entries matching NAME (case insensitive, partial match)\
            from FreeSurfer's FreeSurferColorLUT.txt.
        labeltable_file: Path to the label table file.
        surf_annot_cmap: CMAP file output by FSread_annot's -roi_1D option.
        slab_int: Return the name of an integer labeled area in FreeSurfer's\
            surface-based annotation.
        sname_name: Return the entries matching NAME (case insensitive, partial\
            match) from the CMAP file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VFsRoiLabelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__FS_ROI_LABEL_METADATA)
    cargs = []
    cargs.append("@FS_roi_label")
    if label_int is not None:
        cargs.append(str(label_int))
    if lab_flag is not None:
        cargs.extend([
            "-lab",
            str(lab_flag)
        ])
    if rank_int is not None:
        cargs.extend([
            "-rank",
            str(rank_int)
        ])
    if rankmap_file is not None:
        cargs.extend([
            "-rankmap",
            execution.input_file(rankmap_file)
        ])
    if name is not None:
        cargs.extend([
            "-name",
            name
        ])
    if labeltable_file is not None:
        cargs.extend([
            "-labeltable",
            execution.input_file(labeltable_file)
        ])
    if surf_annot_cmap is not None:
        cargs.extend([
            "-surf_annot_cmap",
            execution.input_file(surf_annot_cmap)
        ])
    if slab_int is not None:
        cargs.extend([
            "-slab",
            str(slab_int)
        ])
    if sname_name is not None:
        cargs.extend([
            "-sname",
            sname_name
        ])
    ret = VFsRoiLabelOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VFsRoiLabelOutputs",
    "V__FS_ROI_LABEL_METADATA",
    "v__fs_roi_label",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BRAIN_SKIN_METADATA = Metadata(
    id="415edd6d3850d9f5c9473cdb97d435d17cef3bb4.boutiques",
    name="BrainSkin",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class BrainSkinOutputs(typing.NamedTuple):
    """
    Output object returned when calling `brain_skin(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    stitch_surface: OutputPathType
    """A bunch of triangles for closing the surface."""
    initial_skin_surface: OutputPathType
    """Initial skin surface"""
    reduced_skin_surface: OutputPathType
    """Reduced mesh version of initial skin surface."""
    inflated_skin_surface: OutputPathType
    """Original surface inflated inside skin surface."""
    patching_voxels: OutputPathType
    """Surface patching voxels."""
    surf_voxels: OutputPathType
    """Voxels inside original surface"""
    skin_voxels: OutputPathType
    """Mix of ptchvox and surfvox."""
    infilled_voxels: OutputPathType
    """Skin vox dataset filled in."""
    node_pairs_results: OutputPathType
    """Results of computations for finding node pairs that span sulci."""
    inflating_surface_results: OutputPathType
    """Results of computations for inflating initial surface inside skin
    surface."""
    segments_display: OutputPathType
    """Segments between node pairs spanning sulci."""


def brain_skin(
    surface: str,
    skingrid_volume: InputPathType,
    prefix: str,
    plimit: float | None = None,
    dlimit: float | None = None,
    segdo: str | None = None,
    voxelize: str | None = None,
    infill: str | None = None,
    out_file: InputPathType | None = None,
    vol_hull: InputPathType | None = None,
    no_zero_attraction: bool = False,
    node_dbg: float | None = None,
    runner: Runner | None = None,
) -> BrainSkinOutputs:
    """
    A program to create an unfolded surface that wraps the brain (skin) and
    Gyrification Indices.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/BrainSkin.html
    
    Args:
        surface: Surface to smooth or the domain over which DSET is defined.
        skingrid_volume: A high-res volume to provide a grid for voxelization\
            steps.
        prefix: Prefix to use for variety of output files.
        plimit: Maximum length of path along surface in mm for node pairing.
        dlimit: Maximum length of Euclidean distance in mm for node pairing.
        segdo: Output a displayable object file that contains segments between\
            paired nodes.
        voxelize: Voxelization method. Choose from: slow: Sure footed but slow,\
            fast: Faster and works OK, mask: Fastest and works OK too (default).
        infill: Infill method. Choose from: slow: proper infill, but not\
            needed, fast: brutish infill, all we need (default).
        out_file: Output intermediary results from skin forming step.
        vol_hull: Deform an Icosahedron to match the convex hull of a mask\
            volume.
        no_zero_attraction: With vol_skin, the surface will try to shrink\
            aggressively, even if there is no promise of non-zero values below.
        node_dbg: Output debugging information for node N for -vol_skin and\
            -vol_hull options.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BrainSkinOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BRAIN_SKIN_METADATA)
    cargs = []
    cargs.append("BrainSkin")
    cargs.append(surface)
    cargs.extend([
        "-skingrid",
        execution.input_file(skingrid_volume)
    ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if plimit is not None:
        cargs.extend([
            "-plimit",
            str(plimit)
        ])
    if dlimit is not None:
        cargs.extend([
            "-dlimit",
            str(dlimit)
        ])
    if segdo is not None:
        cargs.extend([
            "-segdo",
            segdo
        ])
    if voxelize is not None:
        cargs.extend([
            "-voxelize",
            voxelize
        ])
    if infill is not None:
        cargs.extend([
            "-infill",
            infill
        ])
    if out_file is not None:
        cargs.extend([
            "-out",
            execution.input_file(out_file)
        ])
    if vol_hull is not None:
        cargs.extend([
            "-vol_hull",
            execution.input_file(vol_hull)
        ])
    if no_zero_attraction:
        cargs.append("-no_zero_attraction")
    if node_dbg is not None:
        cargs.extend([
            "-node_dbg",
            str(node_dbg)
        ])
    ret = BrainSkinOutputs(
        root=execution.output_file("."),
        stitch_surface=execution.output_file(prefix + ".stitch.gii"),
        initial_skin_surface=execution.output_file(prefix + ".skin.gii"),
        reduced_skin_surface=execution.output_file(prefix + ".skin_simp.gii"),
        inflated_skin_surface=execution.output_file(prefix + ".skin.isotopic.gii"),
        patching_voxels=execution.output_file(prefix + ".ptchvox+orig"),
        surf_voxels=execution.output_file(prefix + ".surfvox+orig"),
        skin_voxels=execution.output_file(prefix + ".skinvox+orig"),
        infilled_voxels=execution.output_file(prefix + ".infilled+orig"),
        node_pairs_results=execution.output_file(prefix + ".niml.dset"),
        inflating_surface_results=execution.output_file(prefix + ".areas.niml.dset"),
        segments_display=execution.output_file(prefix + ".1D.do"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BRAIN_SKIN_METADATA",
    "BrainSkinOutputs",
    "brain_skin",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DCM2NIIX_AFNI_METADATA = Metadata(
    id="d0aaf4cd6aec28169a2517d39316626037b75aae.boutiques",
    name="dcm2niix_afni",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class Dcm2niixAfniOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dcm2niix_afni(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    nifti_files: OutputPathType
    """The main output NIfTI files"""


def dcm2niix_afni(
    runner: Runner | None = None,
) -> Dcm2niixAfniOutputs:
    """
    DICOM to NIfTI converter optimized for AFNI.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/dcm2niix_afni.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Dcm2niixAfniOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DCM2NIIX_AFNI_METADATA)
    cargs = []
    cargs.append("dcm2niix_afni")
    cargs.append("[OPTIONS]")
    cargs.append("<INPUT_FOLDER>")
    ret = Dcm2niixAfniOutputs(
        root=execution.output_file("."),
        nifti_files=execution.output_file("<OUTPUT_DIRECTORY>/*.nii"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DCM2NIIX_AFNI_METADATA",
    "Dcm2niixAfniOutputs",
    "dcm2niix_afni",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

APPLY_VOL_TRANSFORM_METADATA = Metadata(
    id="a82b808f6b4e768b499b6b610c1ffe9a7fcd19a1.boutiques",
    name="apply_vol_transform",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ApplyVolTransformOutputs(typing.NamedTuple):
    """
    Output object returned when calling `apply_vol_transform(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    transformed_file_outfile: OutputPathType | None
    """Path to output file if used normally."""


def apply_vol_transform(
    fs_target: bool = False,
    fsl_reg_file: InputPathType | None = None,
    interp: typing.Literal["trilin", "nearest", "cubic"] | None = None,
    inverse: bool = False,
    invert_morph: bool = False,
    lta_file: InputPathType | None = None,
    lta_inv_file: InputPathType | None = None,
    m3z_file: InputPathType | None = None,
    mni_152_reg: bool = False,
    no_def_m3z_path: bool = False,
    no_resample: bool = False,
    reg_file: InputPathType | None = None,
    reg_header: bool = False,
    source_file: InputPathType | None = None,
    subject: str | None = None,
    subjects_dir: InputPathType | None = None,
    tal: bool = False,
    tal_resolution: float | None = None,
    target_file: InputPathType | None = None,
    transformed_file: InputPathType | None = None,
    xfm_reg_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> ApplyVolTransformOutputs:
    """
    Resamples a volume into another field-of-view using varous types of matrices
    (FreeSurfer, FSL, SPM, and MNI).
    
    Author: Members of the Laboratories for Computational Neuroimaging (LCN) at
    the Athinoula A. Martinos Center for Biomedical Imaging
    
    URL: https://surfer.nmr.mgh.harvard.edu/fswiki/mri_vol2vol
    
    Args:
        fs_target: Use orig.mgz from subject in regfile as target.
        fsl_reg_file: Fslras-to-fslras matrix (fsl format).
        interp: 'trilin' or 'nearest' or 'cubic'. Interpolation method\
            (<trilin> or nearest).
        inverse: Sample from target to source.
        invert_morph: Compute and use the inverse of the non-linear morph to\
            resample the input volume. to be used by --m3z.
        lta_file: Linear transform array file.
        lta_inv_file: Lta, invert.
        m3z_file: This is the morph to be applied to the volume. unless the\
            morph is in mri/transforms (eg.: for talairach.m3z computed by\
            reconall), you will need to specify the full path to this morph and use\
            the --nodefm3zpath flag.
        mni_152_reg: Target mni152 space.
        no_def_m3z_path: To be used with the m3z flag. Instructs the code not\
            to look for the non-linear m3z morph in the default location\
            (subjects_dir/subj/mri/transforms), but instead just use the path\
            indicated in --m3z.
        no_resample: Do not resample; just change vox2ras matrix.
        reg_file: Tkras-to-tkras matrix (tkregister2 format).
        reg_header: Scannerras-to-scannerras matrix = identity.
        source_file: Input volume you wish to transform.
        subject: Set matrix = identity and use subject for any templates.
        subjects_dir: file or string representing an existing directory.\
            Subjects directory.
        tal: Map to a sub fov of mni305 (with --reg only).
        tal_resolution: Resolution to sample when using tal.
        target_file: Output template volume.
        transformed_file: Output volume.
        xfm_reg_file: Scannerras-to-scannerras matrix (mni format).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ApplyVolTransformOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(APPLY_VOL_TRANSFORM_METADATA)
    cargs = []
    cargs.append("mri_vol2vol")
    if fs_target:
        cargs.append("--fstarg")
    if fsl_reg_file is not None:
        cargs.extend([
            "--fsl",
            execution.input_file(fsl_reg_file)
        ])
    if interp is not None:
        cargs.extend([
            "--interp",
            interp
        ])
    if inverse:
        cargs.append("--inv")
    if invert_morph:
        cargs.append("--inv-morph")
    if lta_file is not None:
        cargs.extend([
            "--lta",
            execution.input_file(lta_file)
        ])
    if lta_inv_file is not None:
        cargs.extend([
            "--lta-inv",
            execution.input_file(lta_inv_file)
        ])
    if m3z_file is not None:
        cargs.extend([
            "--m3z",
            execution.input_file(m3z_file)
        ])
    if mni_152_reg:
        cargs.append("--regheader")
    if no_def_m3z_path:
        cargs.append("--noDefM3zPath")
    if no_resample:
        cargs.append("--no-resample")
    if reg_file is not None:
        cargs.extend([
            "--reg",
            execution.input_file(reg_file)
        ])
    if reg_header:
        cargs.append("--regheader")
    if source_file is not None:
        cargs.extend([
            "--mov",
            execution.input_file(source_file)
        ])
    if subject is not None:
        cargs.extend([
            "--s",
            subject
        ])
    if subjects_dir is not None:
        cargs.append(execution.input_file(subjects_dir))
    if tal:
        cargs.append("--tal")
    if tal_resolution is not None:
        cargs.extend([
            "--talres",
            str(tal_resolution)
        ])
    if target_file is not None:
        cargs.extend([
            "--targ",
            execution.input_file(target_file)
        ])
    if transformed_file is not None:
        cargs.extend([
            "--o",
            execution.input_file(transformed_file)
        ])
    if xfm_reg_file is not None:
        cargs.extend([
            "--xfm",
            execution.input_file(xfm_reg_file)
        ])
    ret = ApplyVolTransformOutputs(
        root=execution.output_file("."),
        transformed_file_outfile=execution.output_file(pathlib.Path(transformed_file).name + ".nii.gz") if (transformed_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "APPLY_VOL_TRANSFORM_METADATA",
    "ApplyVolTransformOutputs",
    "apply_vol_transform",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__PURIFY_1_D_METADATA = Metadata(
    id="813b07d61e5f245a5171c379d84ac0cea433dad8.boutiques",
    name="@Purify_1D",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VPurify1DOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__purify_1_d(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__purify_1_d(
    input_files: list[InputPathType],
    sub_brick: str | None = None,
    suffix: str | None = None,
    runner: Runner | None = None,
) -> VPurify1DOutputs:
    """
    Purifies a series of 1D files for faster I/O into matlab.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@Purify_1D.html
    
    Args:
        input_files: Input 1D dataset files.
        sub_brick: The sub-brick selection mode to output a select number of\
            columns, following AFNI conventions.
        suffix: STRING is attached to the output prefix which is formed from\
            the input names.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VPurify1DOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__PURIFY_1_D_METADATA)
    cargs = []
    cargs.append("@Purify_1D")
    if sub_brick is not None:
        cargs.extend([
            "-sub",
            sub_brick
        ])
    if suffix is not None:
        cargs.extend([
            "-suf",
            suffix
        ])
    cargs.extend([execution.input_file(f) for f in input_files])
    ret = VPurify1DOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VPurify1DOutputs",
    "V__PURIFY_1_D_METADATA",
    "v__purify_1_d",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MATHS_METADATA = Metadata(
    id="9e568b59cf33df46aee16c176027f0e617d1ecaf.boutiques",
    name="maths",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


@dataclasses.dataclass
class MathsOperation:
    """
    Operations to perform on input images.
    """
    add: float | None = None
    """Add following input to current image"""
    sub: float | None = None
    """Subtract following input from current image"""
    mul: float | None = None
    """Multiply current image by following input"""
    div: float | None = None
    """Divide current image by following input"""
    rem: float | None = None
    """Modulus remainder - divide current image by following input and take
    remainder"""
    mas: InputPathType | None = None
    """Use (following image>0) to mask current image"""
    thr: float | None = None
    """Use following number to threshold current image (zero anything below the
    number)"""
    thrp: float | None = None
    """Use following percentage (0-100) of ROBUST RANGE to threshold current
    image (zero anything below the number)"""
    thr_p: float | None = None
    """Use following percentage (0-100) of ROBUST RANGE of non-zero voxels and
    threshold below"""
    uthr: float | None = None
    """Use following number to upper-threshold current image (zero anything
    above the number)"""
    uthrp: float | None = None
    """Use following percentage (0-100) of ROBUST RANGE to upper-threshold
    current image (zero anything above the number)"""
    uthr_p: float | None = None
    """Use following percentage (0-100) of ROBUST RANGE of non-zero voxels and
    threshold above"""
    max_: float | None = None
    """Take maximum of following input and current image"""
    min_: float | None = None
    """Take minimum of following input and current image"""
    seed: float | None = None
    """Seed random number generator with following number"""
    restart: InputPathType | None = None
    """Replace the current image with input for future processing operations"""
    save: bool = False
    """Save the current working image to the input filename"""
    exp: bool = False
    """Exponential"""
    log: bool = False
    """Natural logarithm"""
    sin: bool = False
    """Sine function"""
    cos: bool = False
    """Cosine function"""
    tan: bool = False
    """Tangent function"""
    asin: bool = False
    """Arc sine function"""
    acos: bool = False
    """Arc cosine function"""
    atan: bool = False
    """Arc tangent function"""
    sqr: bool = False
    """Square"""
    sqrt: bool = False
    """Square root"""
    recip: bool = False
    """Reciprocal (1/current image)"""
    abs_: bool = False
    """Absolute value"""
    bin_: bool = False
    """Use (current image>0) to binarise"""
    binv: bool = False
    """Binarise and invert (binarisation and logical inversion)"""
    fillh: bool = False
    """Fill holes in a binary mask (holes are internal - i.e. do not touch the
    edge of the FOV)"""
    fillh26: bool = False
    """Fill holes using 26 connectivity"""
    index: bool = False
    """Replace each nonzero voxel with a unique (subject to wrapping) index
    number"""
    grid: list[float] | None = None
    """Add a 3D grid of intensity <value> with grid spacing <spacing>"""
    edge: bool = False
    """Edge strength"""
    tfce: list[float] | None = None
    """Enhance with TFCE, e.g. -tfce 2 0.5 6 (maybe change 6 to 26 for
    skeletons)"""
    tfce_s: list[float] | None = None
    """Show support area for voxel (X,Y,Z)"""
    nan: bool = False
    """Replace NaNs (improper numbers) with 0"""
    nanm: bool = False
    """Make NaN (improper number) mask with 1 for NaN voxels, 0 otherwise"""
    rand: bool = False
    """Add uniform noise (range 0:1)"""
    randn: bool = False
    """Add Gaussian noise (mean=0 sigma=1)"""
    inm: float | None = None
    """Intensity normalisation (per 3D volume mean)"""
    ing: float | None = None
    """Intensity normalisation, global 4D mean"""
    range_: bool = False
    """Set the output calmin/max to full data range"""
    tensor_decomp: bool = False
    """Convert a 4D (6-timepoint) tensor image into L1,2,3,FA,MD,MO,V1,2,3
    (remaining image in pipeline is FA)"""
    kernel_3_d: bool = False
    """3x3x3 box centered on target voxel (set as default kernel)"""
    kernel_2_d: bool = False
    """3x3x1 box centered on target voxel"""
    kernel_box: float | None = None
    """All voxels in a cube of width <size> mm centered on target voxel"""
    kernel_boxv: float | None = None
    """All voxels in a cube of width <size> voxels centered on target voxel"""
    kernel_boxv3: list[float] | None = None
    """All voxels in a cuboid of dimensions X x Y x Z centered on target
    voxel"""
    kernel_gauss: float | None = None
    """Gaussian kernel (sigma in mm, not voxels)"""
    kernel_sphere: float | None = None
    """All voxels in a sphere of radius <size> mm centered on target voxel"""
    kernel_file: InputPathType | None = None
    """Use external file as kernel"""
    dil_m: bool = False
    """Mean Dilation of non-zero voxels"""
    dil_d: bool = False
    """Modal Dilation of non-zero voxels"""
    dil_f: bool = False
    """Maximum filtering of all voxels"""
    dilall: bool = False
    """Apply -dilM repeatedly until the entire FOV is covered"""
    ero: bool = False
    """Erode by zeroing non-zero voxels when zero voxels found in kernel"""
    ero_f: bool = False
    """Minimum filtering of all voxels"""
    fmedian: bool = False
    """Median Filtering"""
    fmean: bool = False
    """Mean filtering, kernel weighted (conventionally used with gauss
    kernel)"""
    fmeanu: bool = False
    """Mean filtering, kernel weighted, un-normalised (gives edge effects)"""
    s: float | None = None
    """Create a gauss kernel of sigma mm and perform mean filtering"""
    subsamp2: bool = False
    """Downsamples image by a factor of 2 (keeping new voxels centred on old)"""
    subsamp2offc: bool = False
    """Downsamples image by a factor of 2 (non-centred)"""
    tmean: bool = False
    """Mean across time"""
    xmean: bool = False
    """Mean across X axis"""
    ymean: bool = False
    """Mean across Y axis"""
    zmean: bool = False
    """Mean across Z axis"""
    tstd: bool = False
    """Standard deviation across time"""
    xstd: bool = False
    """Standard deviation across X axis"""
    ystd: bool = False
    """Standard deviation across Y axis"""
    zstd: bool = False
    """Standard deviation across Z axis"""
    tmax: bool = False
    """Max across time"""
    xmax: bool = False
    """Max across X axis"""
    ymax: bool = False
    """Max across Y axis"""
    zmax: bool = False
    """Max across Z axis"""
    tmaxn: bool = False
    """Time index of max across time"""
    xmaxn: bool = False
    """X index of max across X axis"""
    ymaxn: bool = False
    """Y index of max across Y axis"""
    zmaxn: bool = False
    """Z index of max across Z axis"""
    tmin: bool = False
    """Min across time"""
    xmin: bool = False
    """Min across X axis"""
    ymin: bool = False
    """Min across Y axis"""
    zmin: bool = False
    """Min across Z axis"""
    tmedian: bool = False
    """Median across time"""
    xmedian: bool = False
    """Median across X axis"""
    ymedian: bool = False
    """Median across Y axis"""
    zmedian: bool = False
    """Median across Z axis"""
    tperc: float | None = None
    """Nth percentile (0-100) of FULL RANGE across time"""
    xperc: float | None = None
    """Nth percentile (0-100) of FULL RANGE across X axis"""
    yperc: float | None = None
    """Nth percentile (0-100) of FULL RANGE across Y axis"""
    zperc: float | None = None
    """Nth percentile (0-100) of FULL RANGE across Z axis"""
    tar1: bool = False
    """Temporal AR(1) coefficient (use -odt float and probably demean first)"""
    roi: list[float] | None = None
    """<xmin> <xsize> <ymin> <ysize> <zmin> <zsize> <tmin> <tsize>. Zero outside
    roi (using voxel coordinates). Inputting -1 for a size will set it to the
    full image extent for that dimension."""
    bptf: list[float] | None = None
    """<lowpass> <highpass>. Bandpass temporal filtering (use -odt float and
    probably demean first)"""
    roc: list[float] | None = None
    """<threshold> <output>. ROC analysis"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        if thrp is not None and not (0 <= thrp <= 100): 
            raise ValueError(f"'thrp' must be between 0 <= x <= 100 but was {thrp}")
        if thr_p is not None and not (0 <= thr_p <= 100): 
            raise ValueError(f"'thr_p' must be between 0 <= x <= 100 but was {thr_p}")
        if uthrp is not None and not (0 <= uthrp <= 100): 
            raise ValueError(f"'uthrp' must be between 0 <= x <= 100 but was {uthrp}")
        if uthr_p is not None and not (0 <= uthr_p <= 100): 
            raise ValueError(f"'uthr_p' must be between 0 <= x <= 100 but was {uthr_p}")
        if tperc is not None and not (0 <= tperc <= 100): 
            raise ValueError(f"'tperc' must be between 0 <= x <= 100 but was {tperc}")
        if xperc is not None and not (0 <= xperc <= 100): 
            raise ValueError(f"'xperc' must be between 0 <= x <= 100 but was {xperc}")
        if yperc is not None and not (0 <= yperc <= 100): 
            raise ValueError(f"'yperc' must be between 0 <= x <= 100 but was {yperc}")
        if zperc is not None and not (0 <= zperc <= 100): 
            raise ValueError(f"'zperc' must be between 0 <= x <= 100 but was {zperc}")
        cargs = []
        if self.add is not None:
            cargs.extend([
                "-add",
                str(self.add)
            ])
        if self.sub is not None:
            cargs.extend([
                "-sub",
                str(self.sub)
            ])
        if self.mul is not None:
            cargs.extend([
                "-mul",
                str(self.mul)
            ])
        if self.div is not None:
            cargs.extend([
                "-div",
                str(self.div)
            ])
        if self.rem is not None:
            cargs.extend([
                "-rem",
                str(self.rem)
            ])
        if self.mas is not None:
            cargs.extend([
                "-mas",
                execution.input_file(self.mas)
            ])
        if self.thr is not None:
            cargs.extend([
                "-thr",
                str(self.thr)
            ])
        if self.thrp is not None:
            cargs.extend([
                "-thrp",
                str(self.thrp)
            ])
        if self.thr_p is not None:
            cargs.extend([
                "-thrP",
                str(self.thr_p)
            ])
        if self.uthr is not None:
            cargs.extend([
                "-uthr",
                str(self.uthr)
            ])
        if self.uthrp is not None:
            cargs.extend([
                "-uthrp",
                str(self.uthrp)
            ])
        if self.uthr_p is not None:
            cargs.extend([
                "-uthrP",
                str(self.uthr_p)
            ])
        if self.max_ is not None:
            cargs.extend([
                "-max",
                str(self.max_)
            ])
        if self.min_ is not None:
            cargs.extend([
                "-min",
                str(self.min_)
            ])
        if self.seed is not None:
            cargs.extend([
                "-seed",
                str(self.seed)
            ])
        if self.restart is not None:
            cargs.extend([
                "-restart",
                execution.input_file(self.restart)
            ])
        if self.save:
            cargs.append("-save")
        if self.exp:
            cargs.append("-exp")
        if self.log:
            cargs.append("-log")
        if self.sin:
            cargs.append("-sin")
        if self.cos:
            cargs.append("-cos")
        if self.tan:
            cargs.append("-tan")
        if self.asin:
            cargs.append("-asin")
        if self.acos:
            cargs.append("-acos")
        if self.atan:
            cargs.append("-atan")
        if self.sqr:
            cargs.append("-sqr")
        if self.sqrt:
            cargs.append("-sqrt")
        if self.recip:
            cargs.append("-recip")
        if self.abs_:
            cargs.append("-abs")
        if self.bin_:
            cargs.append("-bin")
        if self.binv:
            cargs.append("-binv")
        if self.fillh:
            cargs.append("-fillh")
        if self.fillh26:
            cargs.append("-fillh26")
        if self.index:
            cargs.append("-index")
        if self.grid is not None:
            cargs.extend([
                "-grid",
                *map(str, self.grid)
            ])
        if self.edge:
            cargs.append("-edge")
        if self.tfce is not None:
            cargs.extend([
                "-tfce",
                *map(str, self.tfce)
            ])
        if self.tfce_s is not None:
            cargs.extend([
                "-tfceS",
                *map(str, self.tfce_s)
            ])
        if self.nan:
            cargs.append("-nan")
        if self.nanm:
            cargs.append("-nanm")
        if self.rand:
            cargs.append("-rand")
        if self.randn:
            cargs.append("-randn")
        if self.inm is not None:
            cargs.extend([
                "-inm",
                str(self.inm)
            ])
        if self.ing is not None:
            cargs.extend([
                "-ing",
                str(self.ing)
            ])
        if self.range_:
            cargs.append("-range")
        if self.tensor_decomp:
            cargs.append("-tensor_decomp")
        if self.kernel_3_d:
            cargs.append("-kernel 3D")
        if self.kernel_2_d:
            cargs.append("-kernel 2D")
        if self.kernel_box is not None:
            cargs.extend([
                "-kernel box",
                str(self.kernel_box)
            ])
        if self.kernel_boxv is not None:
            cargs.extend([
                "-kernel boxv",
                str(self.kernel_boxv)
            ])
        if self.kernel_boxv3 is not None:
            cargs.extend([
                "-kernel boxv3",
                *map(str, self.kernel_boxv3)
            ])
        if self.kernel_gauss is not None:
            cargs.extend([
                "-kernel gauss",
                str(self.kernel_gauss)
            ])
        if self.kernel_sphere is not None:
            cargs.extend([
                "-kernel sphere",
                str(self.kernel_sphere)
            ])
        if self.kernel_file is not None:
            cargs.extend([
                "-kernel file",
                execution.input_file(self.kernel_file)
            ])
        if self.dil_m:
            cargs.append("-dilM")
        if self.dil_d:
            cargs.append("-dilD")
        if self.dil_f:
            cargs.append("-dilF")
        if self.dilall:
            cargs.append("-dilall")
        if self.ero:
            cargs.append("-ero")
        if self.ero_f:
            cargs.append("-eroF")
        if self.fmedian:
            cargs.append("-fmedian")
        if self.fmean:
            cargs.append("-fmean")
        if self.fmeanu:
            cargs.append("-fmeanu")
        if self.s is not None:
            cargs.extend([
                "-s",
                str(self.s)
            ])
        if self.subsamp2:
            cargs.append("-subsamp2")
        if self.subsamp2offc:
            cargs.append("-subsamp2offc")
        if self.tmean:
            cargs.append("-Tmean")
        if self.xmean:
            cargs.append("-Xmean")
        if self.ymean:
            cargs.append("-Ymean")
        if self.zmean:
            cargs.append("-Zmean")
        if self.tstd:
            cargs.append("-Tstd")
        if self.xstd:
            cargs.append("-Xstd")
        if self.ystd:
            cargs.append("-Ystd")
        if self.zstd:
            cargs.append("-Zstd")
        if self.tmax:
            cargs.append("-Tmax")
        if self.xmax:
            cargs.append("-Xmax")
        if self.ymax:
            cargs.append("-Ymax")
        if self.zmax:
            cargs.append("-Zmax")
        if self.tmaxn:
            cargs.append("-Tmaxn")
        if self.xmaxn:
            cargs.append("-Xmaxn")
        if self.ymaxn:
            cargs.append("-Ymaxn")
        if self.zmaxn:
            cargs.append("-Zmaxn")
        if self.tmin:
            cargs.append("-Tmin")
        if self.xmin:
            cargs.append("-Xmin")
        if self.ymin:
            cargs.append("-Ymin")
        if self.zmin:
            cargs.append("-Zmin")
        if self.tmedian:
            cargs.append("-Tmedian")
        if self.xmedian:
            cargs.append("-Xmedian")
        if self.ymedian:
            cargs.append("-Ymedian")
        if self.zmedian:
            cargs.append("-Zmedian")
        if self.tperc is not None:
            cargs.extend([
                "-Tperc",
                str(self.tperc)
            ])
        if self.xperc is not None:
            cargs.extend([
                "-Xperc",
                str(self.xperc)
            ])
        if self.yperc is not None:
            cargs.extend([
                "-Yperc",
                str(self.yperc)
            ])
        if self.zperc is not None:
            cargs.extend([
                "-Zperc",
                str(self.zperc)
            ])
        if self.tar1:
            cargs.append("-Tar1")
        if self.roi is not None:
            cargs.extend([
                "-roi",
                *map(str, self.roi)
            ])
        if self.bptf is not None:
            cargs.extend([
                "-bptf",
                *map(str, self.bptf)
            ])
        if self.roc is not None:
            cargs.extend([
                "-roc",
                *map(str, self.roc)
            ])
        return cargs


class MathsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `maths(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """The main output file produced by fslmaths"""


def maths(
    input_files: list[InputPathType],
    operations: list[MathsOperation],
    output: str,
    datatype_internal: typing.Literal["char", "short", "int", "float", "double", "input"] | None = "float",
    output_datatype: typing.Literal["char", "short", "int", "float", "double", "input"] | None = None,
    runner: Runner | None = None,
) -> MathsOutputs:
    """
    FSL utility for image arithmetic, statistics, and mathematical operations.
    
    Author: FSL Team
    
    Args:
        input_files: Input images for processing.
        operations: Operations to perform on input images.
        output: Output image file.
        datatype_internal: Datatype used internally for calculations.
        output_datatype: Datatype used for the output image.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MathsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MATHS_METADATA)
    cargs = []
    cargs.append("fslmaths")
    if datatype_internal is not None:
        cargs.extend([
            "-dt",
            datatype_internal
        ])
    cargs.extend([execution.input_file(f) for f in input_files])
    cargs.extend([a for c in [s.run(execution) for s in operations] for a in c])
    cargs.append(output)
    if output_datatype is not None:
        cargs.extend([
            "-odt",
            output_datatype
        ])
    ret = MathsOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MATHS_METADATA",
    "MathsOperation",
    "MathsOutputs",
    "maths",
]
